# Copyright 1999-2017 Tencent Ltd.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json
import sys


class AbstractModel(object):
    """Base class for all models."""
    _headers = None

    @property
    def headers(self):
        return self._headers

    @headers.setter
    def headers(self, headers):
        self._headers = headers

    def _serialize(self, allow_none=False, allow_empty=True):
        d = vars(self)
        ret = {}
        for k in d:
            if k.startswith("_"):
                continue
            if isinstance(d[k], AbstractModel):
                r = d[k]._serialize(allow_none)
            elif isinstance(d[k], list):
                r = list()
                for tem in d[k]:
                    if isinstance(tem, AbstractModel):
                        r.append(tem._serialize(allow_none))
                    else:
                        r.append(
                            tem.encode("UTF-8") if isinstance(tem, type(u"")) and sys.version_info[0] == 2 else tem)
            else:
                r = d[k].encode("UTF-8") if isinstance(d[k], type(u"")) and sys.version_info[0] == 2 else d[k]
            if allow_none or r is not None:
                if allow_empty or r not in ("", [], {}):
                    ret[k[0].upper() + k[1:]] = r
        return ret


    def _deserialize(self, params):
        return None

    def to_json_string(self, *args, **kwargs):
        """Serialize obj to a JSON formatted str, ensure_ascii is False by default"""
        if "ensure_ascii" not in kwargs:
            kwargs["ensure_ascii"] = False
        return json.dumps(self._serialize(allow_none=False, allow_empty=False), *args, **kwargs)

    def from_json_string(self, jsonStr):
        """Deserialize a JSON formatted str to a Python object"""
        params = json.loads(jsonStr)
        self._deserialize(params)

    def __repr__(self):
        return "%s" % self.to_json_string(indent=2)



# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# CAM签名/鉴权错误。
AUTHFAILURE = 'AuthFailure'

# 操作失败。
FAILEDOPERATION = 'FailedOperation'

# 内部错误。
INTERNALERROR = 'InternalError'

# 内部服务调用异常。
INTERNALERROR_ACCOUNTCGWERROR = 'InternalError.AccountCgwError'

# 内部服务调用异常。
INTERNALERROR_CAMCGWERROR = 'InternalError.CamCgwError'

# 内部服务调用异常。
INTERNALERROR_CAMERROR = 'InternalError.CamError'

# 内部服务调用异常。
INTERNALERROR_CBSCGWERROR = 'InternalError.CbsCgwError'

# 内部服务调用异常。
INTERNALERROR_CBSERROR = 'InternalError.CbsError'

# 内部服务调用异常。
INTERNALERROR_CDBCGWERROR = 'InternalError.CdbCgwError'

# 内部服务调用异常。
INTERNALERROR_CDBERROR = 'InternalError.CdbError'

# 内部服务调用异常。
INTERNALERROR_CONFIGCGWERROR = 'InternalError.ConfigCgwError'

# 内部服务调用异常。
INTERNALERROR_CVMERROR = 'InternalError.CvmError'

# 内部服务调用异常。
INTERNALERROR_KMSERROR = 'InternalError.KmsError'

# 内部服务调用异常。
INTERNALERROR_PROJECTCGWERROR = 'InternalError.ProjectCgwError'

# 安全组接口调用异常。
INTERNALERROR_SGERROR = 'InternalError.SgError'

# 内部服务调用异常。
INTERNALERROR_TAGERROR = 'InternalError.TagError'

# 内部服务调用异常。
INTERNALERROR_TRADECGWERROR = 'InternalError.TradeCgwError'

# 内部服务调用异常。
INTERNALERROR_VPCCGWERROR = 'InternalError.VpcCgwError'

# 内部服务调用异常。
INTERNALERROR_VPCERROR = 'InternalError.VpcError'

# 内部服务调用异常。
INTERNALERROR_WOODSERVERERROR = 'InternalError.WoodServerError'

# 参数错误。
INVALIDPARAMETER = 'InvalidParameter'

# 无效参数，AppId。
INVALIDPARAMETER_INVALIDAPPID = 'InvalidParameter.InvalidAppId'

# 无效参数，ClusterId。
INVALIDPARAMETER_INVALIDCLUSTERID = 'InvalidParameter.InvalidClusterId'

# 无效的集群名称。
INVALIDPARAMETER_INVALIDINSTANCENAME = 'InvalidParameter.InvalidInstanceName'

# 无效的NodeType。
INVALIDPARAMETER_INVALIDNODETYPE = 'InvalidParameter.InvalidNodeType'

# 无法找到该实例。
RESOURCENOTFOUND_CLUSTERNOTFOUND = 'ResourceNotFound.ClusterNotFound'

# 无法找到该实例。
RESOURCENOTFOUND_INSTANCENOTFOUND = 'ResourceNotFound.InstanceNotFound'

# KeyTab文件上传中，请稍等片刻。
RESOURCENOTFOUND_KEYTABFILENOTREADY = 'ResourceNotFound.KeyTabFileNotReady'

# 无法找到服务组件配置。
RESOURCENOTFOUND_SERVICECONFNOTFOUND = 'ResourceNotFound.ServiceConfNotFound'

# 无法找到该服务组件。
RESOURCENOTFOUND_SERVICEGROUPNOTFOUND = 'ResourceNotFound.ServiceGroupNotFound'

# 操作不支持。
UNSUPPORTEDOPERATION = 'UnsupportedOperation'

# 该服务不支持此操作。
UNSUPPORTEDOPERATION_SERVICENOTSUPPORT = 'UnsupportedOperation.ServiceNotSupport'



# -*- coding: utf-8 -*-
from prettytable import PrettyTable

from tikit.tencentcloud.tione.v20211111 import models


def framework_table(framework_response):
    """

    :param framework_response:
    :type framework_response:   :class:`tikit.tencentcloud.tione.v20211111.models.DescribeTrainingFrameworksResponse`
    :return:
    :rtype:
    """
    table = PrettyTable()
    table.field_names = [
        "框架名称",
        "版本",
        "训练模式"
    ]
    for framework in framework_response.FrameworkInfos:
        for framework_version in framework.VersionInfos:
            table.add_row([
                framework.Name,
                "".join(framework_version.Environment),
                ", ".join(framework_version.TrainingModes)
            ])
    table.align = 'l'
    return table


def framework_str(self):
    return framework_table(self).get_string()


def framework_html(self):
    return framework_table(self).get_html_string()


def bill_specs_table(bill_specs_response):
    """

    :param bill_specs_response:
    :type bill_specs_response:   :class:`tikit.tencentcloud.tione.v20211111.models.DescribeBillingSpecsResponse`
    :return:
    :rtype:
    """
    table = PrettyTable()
    table.field_names = [
        "配置名称",
        "描述",
        "每小时价格（单位：元）"
    ]
    for spec in bill_specs_response.Specs:
        table.add_row([
            spec.SpecName,
            spec.SpecAlias,
            spec.SpecId
        ])
    return table


def bill_specs_str(self):
    return bill_specs_table(self).get_string()


def bill_specs_html(self):
    return bill_specs_table(self).get_html_string()


def taiji_hy_specs_table(taiji_hy_specs_response: models.DescribeTaijiHYSpecsResponse):
    """

    :param taiji_hy_specs_response: the response
    :type taiji_hy_specs_response:   :class:`tikit.tencentcloud.tione.v20211111.models.DescribeTaijiHYSpecsResponse`
    :return: pretty table
    :rtype: PrettyTable
    """
    t = bill_specs_table(taiji_hy_specs_response)
    t.field_names = [
        "配置名称",
        "描述",
        "刊例价（单位：元/时）"
    ]
    return t


def taiji_hy_specs_str(self):
    return taiji_hy_specs_table(self).get_string()


def taiji_hy_specs_html(self):
    return taiji_hy_specs_table(self).get_html_string()


def training_task_table(training_task_response):
    """

    :param training_task_response:
    :type training_task_response:   :class:`tikit.tencentcloud.tione.v20211111.models.DescribeTrainingTasksResponse`
    :return:
    :rtype:
    """
    paid_dict = {
        "PREPAID": {"SW":"从CVM机器中选择","NORMAL":"从TIONE平台购买-包年包月"},
        "POSTPAID_BY_HOUR": {"NONE":"从TIONE平台购买-按量计费"}
    }
    table = PrettyTable()
    table.field_names = [
        "任务ID",
        "名称",
        "训练框架",
        "训练模式",
        "机器来源",
        "占用资源",
        "标签",
        "状态",
        "运行时长",
        "创建者",
        "创建时间",
        "训练开始时间",
        "更新时间"
    ]
    for task in training_task_response.TrainingTaskSet:
        if task.RuntimeInSeconds > 86400:
            time_str = "{}天{}小时{}分{}秒".format(int(task.RuntimeInSeconds / 86400),
                                              int((task.RuntimeInSeconds % 86400) / 3600),
                                              int((task.RuntimeInSeconds % 3600) / 60),
                                              task.RuntimeInSeconds % 60)
        elif task.RuntimeInSeconds > 3600:
            time_str = "{}小时{}分{}秒".format(int(task.RuntimeInSeconds / 3600),
                                           int((task.RuntimeInSeconds % 3600) / 60),
                                           task.RuntimeInSeconds % 60)
        else:
            time_str = "{}分{}秒".format(int(task.RuntimeInSeconds / 60), task.RuntimeInSeconds % 60)
        if len(task.FrameworkName) > 0:
            framework = "{}:{}".format(task.FrameworkName, task.FrameworkEnvironment)
        elif task.AIMarketTemplateId != "":
            framework="内置大模型"
        else:
            framework="自定义镜像"
        # 机器来源
        if task.ChargeType is not None and task.ResourceGroupSWType is not None:
            resourceType = paid_dict.get(task.ChargeType, {}).get(task.ResourceGroupSWType, "UnknownType")
        # 创建者名称
        if task.Uin == task.SubUin:
            subuin_name = task.Uin
        else :
            subuin_name = task.SubUinName
        subuin_name = "{}\n{}".format(subuin_name,task.SubUin)
        resource_info = ""
        if task.ResourceConfigInfos is not None:
            if isinstance(task.ResourceConfigInfos, list) and len(task.ResourceConfigInfos) > 0:
                    for rc in task.ResourceConfigInfos:
                        resource_info += "\n"
                        resource_info += "{} 算力规格:{}C{}G".format(rc.Role, 
                                                                   rc.Cpu/1000, 
                                                                   rc.Memory/1024) 
                        if rc.GpuType is not "":
                            gpu_info = "{}*{}".format(rc.GpuType, rc.Gpu/100)
                            resource_info += gpu_info
                            
        table.add_row([
            task.Id,
            task.Name,
            framework,
            task.TrainingMode,
            resourceType,
            resource_info,
            "\n".join(map(lambda x: "%s:%s" % (x.TagKey, x.TagValue), task.Tags)),
            task.Status,
            time_str,
            subuin_name,
            task.CreateTime,
            task.StartTime,
            task.UpdateTime
        ])
    return table

def pod_list_table(pod_response):
    """
    
    :param pod_response:
    :type pod_response:   :class:`tikit.tencentcloud.tione.v20211111.models.DescribeTrainingTaskPodsResponse`
    :return:
    :rtype:
    """
    table = PrettyTable()
    table.field_names = [
        "实例ID",
        "实例规格",
        "状态",
        "节点ID",
        "启动时间",
        "结束时间",
    ]
    for pod in pod_response.PodInfoList:
        resource_info = ""
        rc = pod.ResourceConfigInfo
        if  rc is not None:
            resource_info += "{} 算力规格:{}C{}G".format(rc.Role, 
                                                        rc.Cpu/1000, 
                                                        rc.Memory/1024) 
            if rc.GpuType is not "":
                gpu_info = "{}*{}".format(rc.GpuType, rc.Gpu/100)
                resource_info += gpu_info
        table.add_row([
            pod.Name,
            resource_info,
            pod.Status,
            pod.NodeId,
            pod.StartTime,
            pod.EndTime
        ])
    return table

def training_task_str(self):
    return training_task_table(self).get_string()


def training_task_html(self):
    return training_task_table(self).get_html_string()

def pod_list_str(self): 
    return pod_list_table(self).get_string()

def pod_list_html(self):
    return pod_list_table(self).get_string()

def log_table(log_response):
    """

    :param log_response:
    :type log_response:   :class:`tikit.tencentcloud.tione.v20211111.models.DescribeLogsResponse`
    :return:
    :rtype:
    """
    table = PrettyTable()
    table.field_names = [
        "日志时间",
        "实例名称",
        "日志数据"
    ]
    for one_log in log_response.Content:
        table.add_row([
            one_log.Timestamp,
            one_log.PodName,
            one_log.Message
        ])
    table.align = 'l'
    return table


def log_str(self):
    return log_table(self).get_string()


def log_html(self):
    return log_table(self).get_html_string()

def params_str_to_dict(input_str):
    input_str = input_str.strip("\"")
    input_str = input_str.strip("{")
    input_str = input_str.strip("}")
    # Split the string into key-value pairs
    key_value_pairs = input_str.split(', ')
    # Create a dictionary from the key-value pairs
    result_dict = {}
    for pair in key_value_pairs:
        key, value = pair.split('=')
        result_dict[key] = value
    return result_dict

models.DescribeTrainingFrameworksResponse.__repr__ = framework_str
models.DescribeTrainingFrameworksResponse._repr_html_ = framework_html

models.DescribeBillingSpecsResponse.__repr__ = bill_specs_str
models.DescribeBillingSpecsResponse._repr_html_ = bill_specs_html

models.DescribeTrainingTasksResponse.__repr__ = training_task_str
models.DescribeTrainingTasksResponse._repr_html_ = training_task_html

models.DescribeTaijiHYSpecsResponse.__repr__ = taiji_hy_specs_str
models.DescribeTaijiHYSpecsResponse._repr_html_ = taiji_hy_specs_html

models.DescribeLogsResponse.__repr__ = log_str
models.DescribeLogsResponse._repr_html_ = log_html

models.DescribeTrainingTaskPodsResponse.__repr__ = pod_list_str
models.DescribeTrainingTaskPodsResponse._repr_html_ = pod_list_html


# -*- coding: utf-8 -*-
from prettytable import PrettyTable

from tikit.tencentcloud.tione.v20211111 import models

def notebook_image_table(buildin_images_response):
    """

    :param buildin_images_response:
    :type buildin_images_response:   :class:`tikit.tencentcloud.tione.v20211111.models.DescribeBuildInImagesResponse`
    :return:
    :rtype:
    """
    table = PrettyTable()
    table.field_names = [
        "内置镜像ID","内置镜像名称"
    ]
    for image_info in buildin_images_response.BuildInImageInfos:
        table.add_row([
            image_info.ImageId,
            image_info.ImageName,
        ])

    table.align = 'l'
    return table


def notebook_image_str(self):
    return notebook_image_table(self).get_string()


def notebook_image_html(self):
    return notebook_image_table(self).get_html_string()


models.DescribeBuildInImagesResponse.__repr__ = notebook_image_str
models.DescribeBuildInImagesResponse._repr_html_ = notebook_image_html


# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import warnings

from tikit.tencentcloud.common.abstract_model import AbstractModel


class DataSourceInfo(AbstractModel):
    """数据源对象

    """

    def __init__(self):
        r"""
        :param DatabaseName: 若数据源列表为绑定数据库，则为db名称
注意：此字段可能返回 null，表示取不到有效值。
        :type DatabaseName: str
        :param Description: 数据源描述信息
注意：此字段可能返回 null，表示取不到有效值。
        :type Description: str
        :param ID: 数据源ID
注意：此字段可能返回 null，表示取不到有效值。
        :type ID: int
        :param Instance: 数据源引擎的实例ID，如CDB实例ID
注意：此字段可能返回 null，表示取不到有效值。
        :type Instance: str
        :param Name: 数据源名称，在相同SpaceName下，数据源名称不能为空
注意：此字段可能返回 null，表示取不到有效值。
        :type Name: str
        :param Region: 数据源引擎所属区域
注意：此字段可能返回 null，表示取不到有效值。
        :type Region: str
        :param Type: 数据源类型:枚举值
注意：此字段可能返回 null，表示取不到有效值。
        :type Type: str
        :param ClusterId: 数据源所属的集群id
注意：此字段可能返回 null，表示取不到有效值。
        :type ClusterId: str
        :param AppId: 应用ID AppId
注意：此字段可能返回 null，表示取不到有效值。
        :type AppId: int
        :param BizParams: 业务侧数据源的配置信息扩展
注意：此字段可能返回 null，表示取不到有效值。
        :type BizParams: str
        :param Category: 数据源类别：绑定引擎、绑定数据库
注意：此字段可能返回 null，表示取不到有效值。
        :type Category: str
        :param Display: 数据源展示名，为了可视化查看
注意：此字段可能返回 null，表示取不到有效值。
        :type Display: str
        :param OwnerAccount: 数据源责任人账号ID
注意：此字段可能返回 null，表示取不到有效值。
        :type OwnerAccount: int
        :param Params: 数据源的配置信息，以JSON KV存储，根据每个数据源类型不同，而KV存储信息不同
注意：此字段可能返回 null，表示取不到有效值。
        :type Params: str
        :type ParamsString: str
        :param Status: 数据源数据源的可见性，1为可见、0为不可见。默认为1
注意：此字段可能返回 null，表示取不到有效值。
        :type Status: int
        :param OwnerAccountName: 数据源责任人账号名称
注意：此字段可能返回 null，表示取不到有效值。
        :type OwnerAccountName: str
        :param ClusterName: 集群名称
注意：此字段可能返回 null，表示取不到有效值。
        :type ClusterName: str
        :param OwnerProjectId: 归属项目ID
注意：此字段可能返回 null，表示取不到有效值。
        :type OwnerProjectId: str
        :param OwnerProjectName: 归属项目Name
注意：此字段可能返回 null，表示取不到有效值。
        :type OwnerProjectName: str
        :param OwnerProjectIdent: 归属项目标识
注意：此字段可能返回 null，表示取不到有效值。
        :type OwnerProjectIdent: str
        :param AuthorityProjectName: 授权项目
注意：此字段可能返回 null，表示取不到有效值。
        :type AuthorityProjectName: str
        :param AuthorityUserName: 授权用户
注意：此字段可能返回 null，表示取不到有效值。
        :type AuthorityUserName: str
        :param Edit: 是否有编辑权限
注意：此字段可能返回 null，表示取不到有效值。
        :type Edit: bool
        :param Author: 是否有授权权限
注意：此字段可能返回 null，表示取不到有效值。
        :type Author: bool
        :param Deliver: 是否有转交权限
注意：此字段可能返回 null，表示取不到有效值。
        :type Deliver: bool
        :param DataSourceStatus: 数据源状态
注意：此字段可能返回 null，表示取不到有效值。
        :type DataSourceStatus: str
        """
        self.DatabaseName = None
        self.Description = None
        self.ID = None
        self.Instance = None
        self.Name = None
        self.Region = None
        self.Type = None
        self.ClusterId = None
        self.AppId = None
        self.BizParams = None
        self.Category = None
        self.Display = None
        self.OwnerAccount = None
        self.Params = None
        self.ParamsString = None
        self.Status = None
        self.OwnerAccountName = None
        self.ClusterName = None
        self.OwnerProjectId = None
        self.OwnerProjectName = None
        self.OwnerProjectIdent = None
        self.AuthorityProjectName = None
        self.AuthorityUserName = None
        self.Edit = None
        self.Author = None
        self.Deliver = None
        self.DataSourceStatus = None


    def _deserialize(self, params):
        self.DatabaseName = params.get("DatabaseName")
        self.Description = params.get("Description")
        self.ID = params.get("ID")
        self.Instance = params.get("Instance")
        self.Name = params.get("Name")
        self.Region = params.get("Region")
        self.Type = params.get("Type")
        self.ClusterId = params.get("ClusterId")
        self.AppId = params.get("AppId")
        self.BizParams = params.get("BizParams")
        self.Category = params.get("Category")
        self.Display = params.get("Display")
        self.OwnerAccount = params.get("OwnerAccount")
        self.Params = params.get("Params")
        self.ParamsString = params.get("ParamsString")
        self.Status = params.get("Status")
        self.OwnerAccountName = params.get("OwnerAccountName")
        self.ClusterName = params.get("ClusterName")
        self.OwnerProjectId = params.get("OwnerProjectId")
        self.OwnerProjectName = params.get("OwnerProjectName")
        self.OwnerProjectIdent = params.get("OwnerProjectIdent")
        self.AuthorityProjectName = params.get("AuthorityProjectName")
        self.AuthorityUserName = params.get("AuthorityUserName")
        self.Edit = params.get("Edit")
        self.Author = params.get("Author")
        self.Deliver = params.get("Deliver")
        self.DataSourceStatus = params.get("DataSourceStatus")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DataSourceInfoPage(AbstractModel):
    """查询数据源分页列表

    """

    def __init__(self):
        r"""
        :param PageNumber: 分页页码
注意：此字段可能返回 null，表示取不到有效值。
        :type PageNumber: int
        :param PageSize: 分页大小
注意：此字段可能返回 null，表示取不到有效值。
        :type PageSize: int
        :param Rows: 数据源列表
注意：此字段可能返回 null，表示取不到有效值。
        :type Rows: :class:`tikit.tencentcloud.wedata.v20210820.models.DataSourceInfo`
        :param TotalCount: 总数
注意：此字段可能返回 null，表示取不到有效值。
        :type TotalCount: int
        :param TotalPageNumber: 总分页页码
注意：此字段可能返回 null，表示取不到有效值。
        :type TotalPageNumber: int
        """
        self.PageNumber = None
        self.PageSize = None
        self.Rows = None
        self.TotalCount = None
        self.TotalPageNumber = None


    def _deserialize(self, params):
        self.PageNumber = params.get("PageNumber")
        self.PageSize = params.get("PageSize")
        if params.get("Rows") is not None:
            self.Rows = DataSourceInfo()
            self.Rows._deserialize(params.get("Rows"))
        self.TotalCount = params.get("TotalCount")
        self.TotalPageNumber = params.get("TotalPageNumber")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DatasourceBaseInfo(AbstractModel):
    """数据源对象

    """

    def __init__(self):
        r"""
        :param DatabaseNames: 若数据源列表为绑定数据库，则为db名称
注意：此字段可能返回 null，表示取不到有效值。
        :type DatabaseNames: list of str
        :param Description: 数据源描述信息
注意：此字段可能返回 null，表示取不到有效值。
        :type Description: str
        :param ID: 数据源ID
        :type ID: int
        :param Instance: 数据源引擎的实例ID，如CDB实例ID
注意：此字段可能返回 null，表示取不到有效值。
        :type Instance: str
        :param Name: 数据源名称，在相同SpaceName下，数据源名称不能为空
        :type Name: str
        :param Region: 数据源引擎所属区域
注意：此字段可能返回 null，表示取不到有效值。
        :type Region: str
        :param Type: 数据源类型:枚举值
注意：此字段可能返回 null，表示取不到有效值。
        :type Type: str
        :param ClusterId: 数据源所属的集群id
注意：此字段可能返回 null，表示取不到有效值。
        :type ClusterId: str
        """
        self.DatabaseNames = None
        self.Description = None
        self.ID = None
        self.Instance = None
        self.Name = None
        self.Region = None
        self.Type = None
        self.ClusterId = None


    def _deserialize(self, params):
        self.DatabaseNames = params.get("DatabaseNames")
        self.Description = params.get("Description")
        self.ID = params.get("ID")
        self.Instance = params.get("Instance")
        self.Name = params.get("Name")
        self.Region = params.get("Region")
        self.Type = params.get("Type")
        self.ClusterId = params.get("ClusterId")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeDataSourceInfoListRequest(AbstractModel):
    """DescribeDataSourceInfoList请求参数结构体

    """

    def __init__(self):
        r"""
        :param ProjectId: 工作空间id
        :type ProjectId: str
        :param PageNumber: 页码
        :type PageNumber: int
        :param PageSize: 页数
        :type PageSize: int
        :param Filters: 可选过滤条件，Filter可选配置(参考): "Name": { "type": "string", "description": "数据源名称" }, "Type": { "type": "string", "description": "类型" }, "ClusterId": { "type": "string", "description": "集群id" }, "CategoryId": { "type": "string", "description": "分类，项目或空间id" }
        :type Filters: :class:`tikit.tencentcloud.wedata.v20210820.models.Filter`
        :param OrderFields: 排序配置
        :type OrderFields: :class:`tikit.tencentcloud.wedata.v20210820.models.OrderField`
        :param Type: 数据源类型
        :type Type: str
        :param DatasourceName: 数据源名称过滤用
        :type DatasourceName: str
        """
        self.ProjectId = None
        self.PageNumber = None
        self.PageSize = None
        self.Filters = None
        self.OrderFields = None
        self.Type = None
        self.DatasourceName = None


    def _deserialize(self, params):
        self.ProjectId = params.get("ProjectId")
        self.PageNumber = params.get("PageNumber")
        self.PageSize = params.get("PageSize")
        if params.get("Filters") is not None:
            self.Filters = Filter()
            self.Filters._deserialize(params.get("Filters"))
        if params.get("OrderFields") is not None:
            self.OrderFields = OrderField()
            self.OrderFields._deserialize(params.get("OrderFields"))
        self.Type = params.get("Type")
        self.DatasourceName = params.get("DatasourceName")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeDataSourceInfoListResponse(AbstractModel):
    """DescribeDataSourceInfoList返回参数结构体

    """

    def __init__(self):
        r"""
        :param TotalCount: 总条数。
        :type TotalCount: int
        :param DatasourceInfoSet: 数据源信息列表。
        :type DatasourceInfoSet: list of DatasourceBaseInfo
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.TotalCount = None
        self.DatasourceInfoSet = None
        self.RequestId = None


    def _deserialize(self, params):
        self.TotalCount = params.get("TotalCount")
        if params.get("DatasourceInfoSet") is not None:
            self.DatasourceInfoSet = []
            for item in params.get("DatasourceInfoSet"):
                obj = DatasourceBaseInfo()
                obj._deserialize(item)
                self.DatasourceInfoSet.append(obj)
        self.RequestId = params.get("RequestId")


class DescribeDataSourceListRequest(AbstractModel):
    """DescribeDataSourceList请求参数结构体

    """

    def __init__(self):
        r"""
        :param PageNumber: 页码
        :type PageNumber: int
        :param PageSize: 返回数量
        :type PageSize: int
        :param OrderFields: 排序配置
        :type OrderFields: list of OrderField
        :param Filters: 可选过滤条件，Filter可选配置(参考): "Name": { "type": "string", "description": "数据源名称" }, "Type": { "type": "string", "description": "类型" }, "ClusterId": { "type": "string", "description": "集群id" }, "CategoryId": { "type": "string", "description": "分类，项目或空间id" }
        :type Filters: list of Filter
        """
        self.PageNumber = None
        self.PageSize = None
        self.OrderFields = None
        self.Filters = None


    def _deserialize(self, params):
        self.PageNumber = params.get("PageNumber")
        self.PageSize = params.get("PageSize")
        if params.get("OrderFields") is not None:
            self.OrderFields = []
            for item in params.get("OrderFields"):
                obj = OrderField()
                obj._deserialize(item)
                self.OrderFields.append(obj)
        if params.get("Filters") is not None:
            self.Filters = []
            for item in params.get("Filters"):
                obj = Filter()
                obj._deserialize(item)
                self.Filters.append(obj)
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeDataSourceListResponse(AbstractModel):
    """DescribeDataSourceList返回参数结构体

    """

    def __init__(self):
        r"""
        :param Data: 数据源列表
注意：此字段可能返回 null，表示取不到有效值。
        :type Data: :class:`tikit.tencentcloud.wedata.v20210820.models.DataSourceInfoPage`
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.Data = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("Data") is not None:
            self.Data = DataSourceInfoPage()
            self.Data._deserialize(params.get("Data"))
        self.RequestId = params.get("RequestId")


class DescribeDatasourceRequest(AbstractModel):
    """DescribeDatasource请求参数结构体

    """

    def __init__(self):
        r"""
        :param Id: 对象唯一ID
        :type Id: int
        """
        self.Id = None


    def _deserialize(self, params):
        self.Id = params.get("Id")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeDatasourceResponse(AbstractModel):
    """DescribeDatasource返回参数结构体

    """

    def __init__(self):
        r"""
        :param Data: 数据源对象
注意：此字段可能返回 null，表示取不到有效值。
        :type Data: :class:`tikit.tencentcloud.wedata.v20210820.models.DataSourceInfo`
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.Data = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("Data") is not None:
            self.Data = DataSourceInfo()
            self.Data._deserialize(params.get("Data"))
        self.RequestId = params.get("RequestId")


class Filter(AbstractModel):
    """通用过滤器

    """

    def __init__(self):
        r"""
        :param Name: 过滤字段名称
        :type Name: str
        :param Values: 过滤值列表
        :type Values: list of str
        """
        self.Name = None
        self.Values = None


    def _deserialize(self, params):
        self.Name = params.get("Name")
        self.Values = params.get("Values")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class OrderField(AbstractModel):
    """通用排序字段

    """

    def __init__(self):
        r"""
        :param Name: 排序字段名称
        :type Name: str
        :param Direction: 排序方向：ASC|DESC
        :type Direction: str
        """
        self.Name = None
        self.Direction = None


    def _deserialize(self, params):
        self.Name = params.get("Name")
        self.Direction = params.get("Direction")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# CAM签名/鉴权错误。
AUTHFAILURE = 'AuthFailure'

# 获取CFS服务角色错误
AUTHFAILURE_GETROLEFAILED = 'AuthFailure.GetRoleFailed'

# 请求未CAM授权。
AUTHFAILURE_UNAUTHORIZEDOPERATION = 'AuthFailure.UnauthorizedOperation'

# 操作失败。
FAILEDOPERATION = 'FailedOperation'

# 调整频率超限
FAILEDOPERATION_ADJUSTFREQUENCYLIMIT = 'FailedOperation.AdjustFrequencyLimit'

# 文件系统绑定资源包失败。
FAILEDOPERATION_BINDRESOURCEPKGFAILED = 'FailedOperation.BindResourcePkgFailed'

# 资源正在创建中。
FAILEDOPERATION_CLIENTTOKENINUSE = 'FailedOperation.ClientTokenInUse'

# 文件系统存在挂载点。
FAILEDOPERATION_MOUNTTARGETEXISTS = 'FailedOperation.MountTargetExists'

# 权限组已绑定文件系统。
FAILEDOPERATION_PGROUPINUSE = 'FailedOperation.PgroupInUse'

# 权限组正在更新中。
FAILEDOPERATION_PGROUPISUPDATING = 'FailedOperation.PgroupIsUpdating'

# 该权限组关联了旧版本实例，请解除关联后重试。
FAILEDOPERATION_PGROUPLINKCFSV10 = 'FailedOperation.PgroupLinkCfsv10'

# 解绑资源标签失败。
FAILEDOPERATION_UNTAGRESOURCEFAILED = 'FailedOperation.UntagResourceFailed'

# 内部错误。
INTERNALERROR = 'InternalError'

# 创建文件系统失败。
INTERNALERROR_CREATEFSFAILED = 'InternalError.CreateFsFailed'

# 获取用户费用状态失败。
INTERNALERROR_GETACCOUNTSTATUSFAILED = 'InternalError.GetAccountStatusFailed'

# 参数错误。
INVALIDPARAMETER = 'InvalidParameter'

# 快照策略未找到。
INVALIDPARAMETER_AUTOPOLICYNOTFOUND = 'InvalidParameter.AutoPolicyNotFound'

# 无效的快照保留时间。
INVALIDPARAMETER_INVALIDALIVEDDAYS = 'InvalidParameter.InvalidAlivedDays'

# 定期星期参数无效。
INVALIDPARAMETER_INVALIDPARAMDAYOFWEEK = 'InvalidParameter.InvalidParamDayofWeek'

# 定期小时 参数值错误。
INVALIDPARAMETER_INVALIDPARAMHOUR = 'InvalidParameter.InvalidParamHour'

# 无效的快照策略状态。
INVALIDPARAMETER_INVALIDSNAPPOLICYSTATUS = 'InvalidParameter.InvalidSnapPolicyStatus'

# 无效的文件系统快照参数名称 。
INVALIDPARAMETER_INVALIDSNAPSHOTNAME = 'InvalidParameter.InvalidSnapshotName'

# 无效的文件系统快照策略名称。
INVALIDPARAMETER_INVALIDSNAPSHOTPOLICYNAME = 'InvalidParameter.InvalidSnapshotPolicyName'

# 缺少策略相关参数。
INVALIDPARAMETER_MISSINGPOLICYPARAM = 'InvalidParameter.MissingPolicyParam'

# 文件系统快照名称超出上限。
INVALIDPARAMETER_SNAPSHOTNAMELIMITEXCEEDED = 'InvalidParameter.SnapshotNameLimitExceeded'

# 文件系统快照策略名称超过限制。
INVALIDPARAMETER_SNAPSHOTPOLICYNAMELIMITEXCEEDED = 'InvalidParameter.SnapshotPolicyNameLimitExceeded'

# 参数取值错误。
INVALIDPARAMETERVALUE = 'InvalidParameterValue'

# 自动扩容策略不存在
INVALIDPARAMETERVALUE_AUTOPOLICYNOTFOUND = 'InvalidParameterValue.AutoPolicyNotFound'

# 用于保证请求幂等性的字符串长度超过限制（不能超过64字节）。
INVALIDPARAMETERVALUE_CLIENTTOKENLIMITEXCEEDED = 'InvalidParameterValue.ClientTokenLimitExceeded'

# 权限组名称重复。
INVALIDPARAMETERVALUE_DUPLICATEDPGROUPNAME = 'InvalidParameterValue.DuplicatedPgroupName'

# 规则IP重复。
INVALIDPARAMETERVALUE_DUPLICATEDRULEAUTHCLIENTIP = 'InvalidParameterValue.DuplicatedRuleAuthClientIp'

# 标签键重复
INVALIDPARAMETERVALUE_DUPLICATEDTAGKEY = 'InvalidParameterValue.DuplicatedTagKey'

# 用户自定义名称过长（超过64字节)。
INVALIDPARAMETERVALUE_FSNAMELIMITEXCEEDED = 'InvalidParameterValue.FsNameLimitExceeded'

# 文件系统配额设置超出上限。
INVALIDPARAMETERVALUE_FSSIZELIMITEXCEEDED = 'InvalidParameterValue.FsSizeLimitExceeded'

# 无效的AliveDays值错误
INVALIDPARAMETERVALUE_INVALIDALIVEDAYS = 'InvalidParameterValue.InvalidAliveDays'

# 规则IP错误。
INVALIDPARAMETERVALUE_INVALIDAUTHCLIENTIP = 'InvalidParameterValue.InvalidAuthClientIp'

# 扩容策略参数无效
INVALIDPARAMETERVALUE_INVALIDAUTOSCALEUPPARAMS = 'InvalidParameterValue.InvalidAutoScaleUpParams'

# 用于保证请求幂等性的字符串错误。
INVALIDPARAMETERVALUE_INVALIDCLIENTTOKEN = 'InvalidParameterValue.InvalidClientToken'

# 快照跨地域复制参数不支持该地域
INVALIDPARAMETERVALUE_INVALIDDESTINATIONREGIONS = 'InvalidParameterValue.InvalidDestinationRegions'

# 加密参数错误。
INVALIDPARAMETERVALUE_INVALIDENCRYPTED = 'InvalidParameterValue.InvalidEncrypted'

# FileSystemId无效。
INVALIDPARAMETERVALUE_INVALIDFILESYSTEMID = 'InvalidParameterValue.InvalidFileSystemId'

# 无效的自定义名称。
INVALIDPARAMETERVALUE_INVALIDFSNAME = 'InvalidParameterValue.InvalidFsName'

# 无效的文件系统配额。
INVALIDPARAMETERVALUE_INVALIDFSSIZELIMIT = 'InvalidParameterValue.InvalidFsSizeLimit'

# 无效的文件系统状态。
INVALIDPARAMETERVALUE_INVALIDFSSTATUS = 'InvalidParameterValue.InvalidFsStatus'

# 错误的挂载点IP。
INVALIDPARAMETERVALUE_INVALIDMOUNTTARGETIP = 'InvalidParameterValue.InvalidMountTargetIp'

# 无效的网络类型。
INVALIDPARAMETERVALUE_INVALIDNETINTERFACE = 'InvalidParameterValue.InvalidNetInterface'

# DayOfMonth 参数错误
INVALIDPARAMETERVALUE_INVALIDPARAMDAYOFMONTH = 'InvalidParameterValue.InvalidParamDayOfMonth'

# 无效的参数，DayOfWeek
INVALIDPARAMETERVALUE_INVALIDPARAMDAYOFWEEK = 'InvalidParameterValue.InvalidParamDayOfWeek'

# IntervalDays 参数值错误
INVALIDPARAMETERVALUE_INVALIDPARAMINTERVALDAYS = 'InvalidParameterValue.InvalidParamIntervalDays'

# 权限组不属于该用户。
INVALIDPARAMETERVALUE_INVALIDPGROUP = 'InvalidParameterValue.InvalidPgroup'

# 权限组ID无效。
INVALIDPARAMETERVALUE_INVALIDPGROUPID = 'InvalidParameterValue.InvalidPgroupId'

# 无效的权限组名称。
INVALIDPARAMETERVALUE_INVALIDPGROUPNAME = 'InvalidParameterValue.InvalidPgroupName'

# 优先级设置错误。
INVALIDPARAMETERVALUE_INVALIDPRIORITY = 'InvalidParameterValue.InvalidPriority'

# 协议参数错误。
INVALIDPARAMETERVALUE_INVALIDPROTOCOL = 'InvalidParameterValue.InvalidProtocol'

# 设置配额的参数错误，UserId 跟DirectoryPath不可同时填写，两个参数必填一个
INVALIDPARAMETERVALUE_INVALIDQUOTAUSERIDORCFSDIRPATH = 'InvalidParameterValue.InvalidQuotaUserIdOrCfsDirPath'

# 用户区域选择错误 (ZoneName) 或 (ZoneId, Region)二者必选一。
INVALIDPARAMETERVALUE_INVALIDREGIONZONEINFO = 'InvalidParameterValue.InvalidRegionZoneInfo'

# 参数值错误: 资源标签值错误。
INVALIDPARAMETERVALUE_INVALIDRESOURCETAGS = 'InvalidParameterValue.InvalidResourceTags'

# 读写权限设置错误。
INVALIDPARAMETERVALUE_INVALIDRWPERMISSION = 'InvalidParameterValue.InvalidRwPermission'

# 扩容目标容量参数错误
INVALIDPARAMETERVALUE_INVALIDSCALEUPTARGETCAPACITY = 'InvalidParameterValue.InvalidScaleupTargetCapacity'

# 无效的快照策略状态
INVALIDPARAMETERVALUE_INVALIDSNAPPOLICYSTATUS = 'InvalidParameterValue.InvalidSnapPolicyStatus'

# 无效的快照名称
INVALIDPARAMETERVALUE_INVALIDSNAPSHOTNAME = 'InvalidParameterValue.InvalidSnapshotName'

# 无效的快照策略名称
INVALIDPARAMETERVALUE_INVALIDSNAPSHOTPOLICYNAME = 'InvalidParameterValue.InvalidSnapshotPolicyName'

# 无效的快照状态。
INVALIDPARAMETERVALUE_INVALIDSNAPSHOTSTATUS = 'InvalidParameterValue.InvalidSnapshotStatus'

# 资源包不存在或已绑定。
INVALIDPARAMETERVALUE_INVALIDSTORAGERESOURCEPKG = 'InvalidParameterValue.InvalidStorageResourcePkg'

# 存储类型参数错误。
INVALIDPARAMETERVALUE_INVALIDSTORAGETYPE = 'InvalidParameterValue.InvalidStorageType'

# 无效的子网ID。
INVALIDPARAMETERVALUE_INVALIDSUBNETID = 'InvalidParameterValue.InvalidSubnetId'

# 标签键不能为空。
INVALIDPARAMETERVALUE_INVALIDTAGKEY = 'InvalidParameterValue.InvalidTagKey'

# 标签值为空或字符无效。
INVALIDPARAMETERVALUE_INVALIDTAGVALUE = 'InvalidParameterValue.InvalidTagValue'

# 无效的容量值。
INVALIDPARAMETERVALUE_INVALIDTURBOCAPACITY = 'InvalidParameterValue.InvalidTurboCapacity'

# 用户权限设置错误。
INVALIDPARAMETERVALUE_INVALIDUSERPERMISSION = 'InvalidParameterValue.InvalidUserPermission'

# 用户指定不可用的vip。
INVALIDPARAMETERVALUE_INVALIDVIP = 'InvalidParameterValue.InvalidVip'

# 无效的VPCID。
INVALIDPARAMETERVALUE_INVALIDVPCID = 'InvalidParameterValue.InvalidVpcId'

# VPC参数错误。
INVALIDPARAMETERVALUE_INVALIDVPCPARAMETER = 'InvalidParameterValue.InvalidVpcParameter'

# 无效的可用区。
INVALIDPARAMETERVALUE_INVALIDZONEID = 'InvalidParameterValue.InvalidZoneId'

# 无效的可用区或可用区ID。
INVALIDPARAMETERVALUE_INVALIDZONEORZONEID = 'InvalidParameterValue.InvalidZoneOrZoneId'

# FileSystemId缺失。
INVALIDPARAMETERVALUE_MISSINGFILESYSTEMID = 'InvalidParameterValue.MissingFileSystemId'

# 用户参数选择错误 (FileSystemId) 或 (Region)二者必选一。
INVALIDPARAMETERVALUE_MISSINGFILESYSTEMIDORREGION = 'InvalidParameterValue.MissingFileSystemIdOrRegion'

# FileSystem参数缺失。
INVALIDPARAMETERVALUE_MISSINGFSPARAMETER = 'InvalidParameterValue.MissingFsParameter'

# 密钥ID或ARN参数缺失。
INVALIDPARAMETERVALUE_MISSINGKMSKEYID = 'InvalidParameterValue.MissingKmsKeyId'

# 权限组名称和描述不能同时为空。
INVALIDPARAMETERVALUE_MISSINGNAMEORDESCINFO = 'InvalidParameterValue.MissingNameOrDescinfo'

# 权限组名称不能为空。
INVALIDPARAMETERVALUE_MISSINGPGROUPNAME = 'InvalidParameterValue.MissingPgroupName'

# 缺少快照策略参数
INVALIDPARAMETERVALUE_MISSINGPOLICYPARAM = 'InvalidParameterValue.MissingPolicyParam'

# 缺少参数Snapshot Name，或者aliveDays
INVALIDPARAMETERVALUE_MISSINGSNAPNAMEORALIVEDAY = 'InvalidParameterValue.MissingSnapNameOrAliveDay'

# 未绑定存储包。
INVALIDPARAMETERVALUE_MISSINGSTORAGERESOURCEPKG = 'InvalidParameterValue.MissingStorageResourcePkg'

# SUBNETID和UNSUBNETID不能同时为空。
INVALIDPARAMETERVALUE_MISSINGSUBNETIDORUNSUBNETID = 'InvalidParameterValue.MissingSubnetidOrUnsubnetid'

# VPC相关参数缺失。
INVALIDPARAMETERVALUE_MISSINGVPCPARAMETER = 'InvalidParameterValue.MissingVpcParameter'

# VPCID和UNVPCID不能同时为空。
INVALIDPARAMETERVALUE_MISSINGVPCIDORUNVPCID = 'InvalidParameterValue.MissingVpcidOrUnvpcid'

# ZoneID缺失。
INVALIDPARAMETERVALUE_MISSINGZONEID = 'InvalidParameterValue.MissingZoneId'

# 用户区域选择错误 (Zone) 或 (Zone_id)二者必选一。
INVALIDPARAMETERVALUE_MISSINGZONEORZONEID = 'InvalidParameterValue.MissingZoneOrZoneId'

# 权限组描述长度超过限制（不能超过255字节）。
INVALIDPARAMETERVALUE_PGROUPDESCINFOLIMITEXCEEDED = 'InvalidParameterValue.PgroupDescinfoLimitExceeded'

# 权限组名称长度超过限制（不能超过64字节）。
INVALIDPARAMETERVALUE_PGROUPNAMELIMITEXCEEDED = 'InvalidParameterValue.PgroupNameLimitExceeded'

# 目录配额设置的目录嵌套
INVALIDPARAMETERVALUE_PROJECTQUOTASDIRNESTED = 'InvalidParameterValue.ProjectQuotasDirNested'

# 目录配额数量超限
INVALIDPARAMETERVALUE_PROJECTQUOTASEXCEEDED = 'InvalidParameterValue.ProjectQuotasExceeded'

# 容量硬限制取值范围错误。
INVALIDPARAMETERVALUE_QUOTACAPLIMITERROR = 'InvalidParameterValue.QuotaCapLimitError'

# 文件硬限制取值范围错误。
INVALIDPARAMETERVALUE_QUOTAFILELIMITERROR = 'InvalidParameterValue.QuotaFileLimitError'

# USER ID类型错误。
INVALIDPARAMETERVALUE_QUOTAUSERIDERROR = 'InvalidParameterValue.QuotaUserIdError'

# 配额类型错误。
INVALIDPARAMETERVALUE_QUOTAUSERTYPEERROR = 'InvalidParameterValue.QuotaUserTypeError'

# 权限组规则和权限组不匹配。
INVALIDPARAMETERVALUE_RULENOTMATCHPGROUP = 'InvalidParameterValue.RuleNotMatchPgroup'

# 快照名称超限制，名称长度不超过64位字符
INVALIDPARAMETERVALUE_SNAPSHOTNAMELIMITEXCEEDED = 'InvalidParameterValue.SnapshotNameLimitExceeded'

# 快照策略名称超过64位限制
INVALIDPARAMETERVALUE_SNAPSHOTPOLICYNAMELIMITEXCEEDED = 'InvalidParameterValue.SnapshotPolicyNameLimitExceeded'

# 参数值错误: 标签键个数超过上限（6个）。
INVALIDPARAMETERVALUE_TAGKEYFILTERLIMITEXCEEDED = 'InvalidParameterValue.TagKeyFilterLimitExceeded'

# 标签键长度超过限制（不能超过127字节）。
INVALIDPARAMETERVALUE_TAGKEYLIMITEXCEEDED = 'InvalidParameterValue.TagKeyLimitExceeded'

# 标签值个数超过上限（10个）。
INVALIDPARAMETERVALUE_TAGVALUEFILTERLIMITEXCEEDED = 'InvalidParameterValue.TagValueFilterLimitExceeded'

# 标签值长度超过限制（不能超过255字节）。
INVALIDPARAMETERVALUE_TAGVALUELIMITEXCEEDED = 'InvalidParameterValue.TagValueLimitExceeded'

# 该可用区无法提供服务。
INVALIDPARAMETERVALUE_UNAVAILABLEREGION = 'InvalidParameterValue.UnavailableRegion'

# 该地域无法提供服务。
INVALIDPARAMETERVALUE_UNAVAILABLEZONE = 'InvalidParameterValue.UnavailableZone'

# ZoneId和Region不匹配。
INVALIDPARAMETERVALUE_ZONEIDREGIONNOTMATCH = 'InvalidParameterValue.ZoneIdRegionNotMatch'

# 缺少参数错误。
MISSINGPARAMETER = 'MissingParameter'

# 操作被拒绝。
OPERATIONDENIED = 'OperationDenied'

# 资源被占用。
RESOURCEINUSE = 'ResourceInUse'

# 文件系统数量达到上限。
RESOURCEINSUFFICIENT_FILESYSTEMLIMITEXCEEDED = 'ResourceInsufficient.FileSystemLimitExceeded'

# 权限组数量达到上限。
RESOURCEINSUFFICIENT_PGROUPNUMBERLIMITEXCEEDED = 'ResourceInsufficient.PgroupNumberLimitExceeded'

# 区域资源售罄。
RESOURCEINSUFFICIENT_REGIONSOLDOUT = 'ResourceInsufficient.RegionSoldOut'

# 规则条数超过上限。
RESOURCEINSUFFICIENT_RULELIMITEXCEEDED = 'ResourceInsufficient.RuleLimitExceeded'

# 文件系统过大，不支持快照
RESOURCEINSUFFICIENT_SNAPSHOTSIZELIMITEXCEEDED = 'ResourceInsufficient.SnapshotSizeLimitExceeded'

# 该子网下已无可用IP。
RESOURCEINSUFFICIENT_SUBNETIPALLOCCUPIED = 'ResourceInsufficient.SubnetIpAllOccupied'

# 该资源的标签个数达到最大限制。
RESOURCEINSUFFICIENT_TAGLIMITEXCEEDED = 'ResourceInsufficient.TagLimitExceeded'

# 标签限额不足。
RESOURCEINSUFFICIENT_TAGQUOTASEXCEEDED = 'ResourceInsufficient.TagQuotasExceeded'

# Turbo类型特殊容量文件系统数量限制
RESOURCEINSUFFICIENT_TURBOSPECIALCAPACITYFILESYSTEMCOUNTLIMIT = 'ResourceInsufficient.TurboSpecialCapacityFileSystemCountLimit'

# 资源不存在。
RESOURCENOTFOUND = 'ResourceNotFound'

# 该文件系统不存在。
RESOURCENOTFOUND_FILESYSTEMNOTFOUND = 'ResourceNotFound.FileSystemNotFound'

# 文件系统不存在。
RESOURCENOTFOUND_FSNOTEXIST = 'ResourceNotFound.FsNotExist'

# 挂载点不存在。
RESOURCENOTFOUND_MOUNTTARGETNOTFOUND = 'ResourceNotFound.MountTargetNotFound'

# 权限组不存在。
RESOURCENOTFOUND_PGROUPNOTFOUND = 'ResourceNotFound.PgroupNotFound'

# 资源不存在：资源ID 不存在。
RESOURCENOTFOUND_RESOURCEPACKAGENOTFOUND = 'ResourceNotFound.ResourcePackageNotFound'

# 权限规则不存在。
RESOURCENOTFOUND_RULENOTFOUND = 'ResourceNotFound.RuleNotFound'

# 快照ID 不存在。
RESOURCENOTFOUND_SNAPSHOTNOTFOUND = 'ResourceNotFound.SnapshotNotFound'

# 未授权操作。
UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'

# 操作不支持。
UNSUPPORTEDOPERATION = 'UnsupportedOperation'

# 该可用区不支持基础网络。
UNSUPPORTEDOPERATION_BASICNETINTERFACENOTSUPPORTED = 'UnsupportedOperation.BasicNetInterfaceNotSupported'

# appid不在kms白名单(kms目前是白名单开启状态)。
UNSUPPORTEDOPERATION_MISSINGKMSACCESSPERMISSION = 'UnsupportedOperation.MissingKmsAccessPermission'

# 用户已欠费, 请充值后重试。
UNSUPPORTEDOPERATION_OUTOFSERVICE = 'UnsupportedOperation.OutOfService'

# cfs角色未被授权。
UNSUPPORTEDOPERATION_UNAUTHORIZEDCFSQCSROLE = 'UnsupportedOperation.UnauthorizedCfsQcsRole'

# 用户未经过实名认证。
UNSUPPORTEDOPERATION_UNVERIFIEDUSER = 'UnsupportedOperation.UnverifiedUser'



# -*- coding: utf-8 -*-
import os

from deprecated import deprecated

from tikit.tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException

IMAGE_TYPES = ["SYSTEM", "CCR", "TCR"]


class ResourceConfigInfo:
    """资源配置

    """

    def __init__(self, charge_type, instance_type=None, instance_num=None, cpu=None, memory=None, gpu_type=None,
                 gpu=None):
        r"""
        :param instance_type: 算力规格ID
        :type instance_type: str
        :param instance_num: 计算节点数
        :type instance_num: int
        :param cpu: cpu核数，1000=1核
        :type cpu: int
        :param memory: 内存，单位为MB
        :type memory: int
        :param gpu_type: gpu卡类型
        :type gpu_type: str
        :param gpu: gpu数
        :type gpu: int
        """
        self.ChargeType = charge_type
        self.InstanceNum = instance_num
        self.Cpu = cpu
        self.Memory = memory
        self.GpuType = gpu_type
        self.Gpu = gpu
        self.InstanceType = instance_type

    @staticmethod
    def new_postpaid(instance_type, instance_num=1):
        """获取后付费模式下的资源配置

        :param instance_type:   实例类型。通过 describe_postpaid_training_price() 查看实例列表
        :type instance_type:    str
        :param instance_num:    实例数量
        :type instance_num:     int
        :return:
        :rtype:
        """
        return ResourceConfigInfo(charge_type="POSTPAID_BY_HOUR", instance_type=instance_type,
                                  instance_num=instance_num)

    @staticmethod
    def new_prepaid(cpu, memory, gpu=0, gpu_type=None, instance_num=1):
        """获取预付费模式下的资源配置

        :param cpu:     CPU个数，单位是核
        :type cpu:      float
        :param memory:  内存大小，单位是GB
        :type memory:   float
        :param gpu_type: gpu类型
        :type gpu_type: str
        :param gpu:     gpu个数
        :type gpu:      float
        :param instance_num:    实例数量
        :type instance_num:     int
        :return:
        :rtype:
        """
        cpu = int(cpu * 1000)
        memory = int(memory * 1024)
        gpu = int(gpu * 100)
        return ResourceConfigInfo(charge_type="PREPAID", cpu=cpu, memory=memory, gpu=gpu,
                                  gpu_type=gpu_type, instance_num=instance_num)


class ModelServiceResourceConfigInfo:
    """模型服务资源配置

    """

    def __init__(self, charge_type, instance_type=None, cpu=None, memory=None, gpu_type=None,
                 gpu=None):
        r"""
        :param instance_type: 算力规格ID
        :type instance_type: str
        :param cpu: cpu核数，1000=1核
        :type cpu: int
        :param memory: 内存，单位为MB
        :type memory: int
        :param gpu_type: gpu卡类型
        :type gpu_type: str
        :param gpu: gpu数
        :type gpu: int
        """
        self.ChargeType = charge_type
        self.Cpu = cpu
        self.Memory = memory
        self.GpuType = gpu_type
        self.Gpu = gpu
        self.InstanceType = instance_type

    @staticmethod
    def new_postpaid(instance_type):
        """获取后付费模式下的资源配置

        :param instance_type:   实例类型。通过 describe_postpaid_training_price() 查看实例列表
        :type instance_type:    str
        :return:
        :rtype:
        """
        return ResourceConfigInfo(charge_type="POSTPAID_BY_HOUR", instance_type=instance_type)

    @staticmethod
    def new_prepaid(cpu, memory, gpu=0, gpu_type=None):
        """获取预付费模式下的资源配置

        :param cpu:     CPU个数，单位是核
        :type cpu:      float
        :param memory:  内存大小，单位是GB
        :type memory:   float
        :param gpu_type: gpu类型
        :type gpu_type: str
        :param gpu:     gpu个数
        :type gpu:      float
        :return:
        :rtype:
        """
        cpu = int(cpu * 1000)
        memory = int(memory * 1024)
        gpu = int(gpu * 100)
        return ResourceConfigInfo(charge_type="PREPAID", cpu=cpu, memory=memory, gpu=gpu,
                                  gpu_type=gpu_type)
       
    @staticmethod
    def new_hybridpaid(instance_type):
        """获取预付费模式下的资源配置

        :param instance_type:     后付费单副本的实例类型。通过 describe_postpaid_training_price() 查看实例列表
        :type instance_type:      float
        :return:
        :rtype:
        """
        return ResourceConfigInfo(charge_type="HYBRID_PAID",
                                  instance_type=instance_type)


class FrameworkInfo:

    def __init__(self, name, training_mode, framework_environment=None, image_type=None, image_url=None,
                 registry_region=None, registry_id=None):
        self.Name = name
        self.TrainingMode = training_mode

        self.FrameworkEnvironment = framework_environment

        self.ImageType = image_type
        self.ImageUrl = image_url
        self.RegistryRegion = registry_region
        self.RegistryId = registry_id

    @staticmethod
    def new_custom(training_mode, image_type, image_url, registry_region=None, registry_id=None,
                    ):
        """自定义训练框架的配置 通过describe_training_frameworks()查看列表

        :param training_mode:   训练模式，如"DDP"，仅训练任务需要配置
        :type training_mode:    str
        :param image_type:      镜像类型，CCR腾讯云容器镜像服务个人版，TCR腾讯云容器镜像服务企业版，CUSTOM第三方自定义镜像
        :type image_type:       str
        :param image_url:       镜像地址 必填
        :type image_url:        str
        :param registry_region: 腾讯云容器镜像服务的镜像仓库的地域
        :type registry_region:  str
        :param registry_id:     腾讯云容器镜像服务的镜像仓库ID
        :type registry_id:      str
        :return:
        :rtype:
        """
        return FrameworkInfo(name="CUSTOM",
                             training_mode=training_mode,
                             image_type=image_type,
                             image_url=image_url,
                             registry_region=registry_region,
                             registry_id=registry_id)
        
    def new_custom_image(image_type, image_url, registry_region=None, registry_id=None):
        """自定义镜像的配置

        :param image_type:      腾讯云容器镜像服务的镜像类型，如"CCR"
        :type image_type:       str
        :param image_url:       腾讯云容器镜像服务的镜像地址
        :type image_url:        str
        :param registry_region: 腾讯云容器镜像服务的镜像仓库的域
        :type registry_region:  str
        :param registry_id:     腾讯云容器镜像服务的镜像仓库ID
        :type registry_id:      str
        :return:
        :rtype:
        """
        return FrameworkInfo(name="CUSTOM",
                             training_mode="",
                             image_type=image_type,
                             image_url=image_url,
                             registry_region=registry_region,
                             registry_id=registry_id)

    @staticmethod
    def new_system_framework(framework_name, framework_environment, training_mode):
        """系统内置的训练框架

        :param framework_name:      框架名称。 通过describe_training_frameworks()查看列表
        :type framework_name:       str
        :param framework_environment:   框架环境。 通过describe_training_frameworks()查看列表
        :type framework_environment:    str
        :param training_mode:       训练模式。 通过describe_training_frameworks()查看列表
        :type training_mode:        str
        :return:
        :rtype:
        """
        return FrameworkInfo(name=framework_name,
                             framework_environment=framework_environment,
                             training_mode=training_mode)

class TrainingDataConfig:
    def __init__(self):
        self.DataSource = None
        self.DataConfigDict = None  # Deprecated
        self.DataSourceUsage = None
        self.TargetPath = None
        self.CosStr = None
        self.DatasetId = None
        self.CfsId = None
        self.CfsPath = None
        self.HdfsId = None
        self.HdfsPath = None
        self.WedataId = None
        self.AIMarketAlgoId = None
        self.AIMarketAlgoGroup = None
        self.GooseFSId = None
        self.GooseFSPath = None
        self.GooseFSNameSpace = None
        self.GooseFSxId = None
        self.GooseFSxPath = None
        self.CFSTurboId = None
        self.CFSTurboPath = None

    @staticmethod
    def new_mount_cos(cos_str, target_path):
        """一个cos类型的训练数据

        :param cos_str:      cos存储，格式： <bucket>/<cos path>/
        :type cos_str: str
        :param  target_path:  目标挂载路径
        :type target_path: str
        :return:
        :rtype:
        """
        ret = TrainingDataConfig()
        ret.TargetPath = target_path
        ret.DataSource = "COS"
        ret.CosStr = cos_str
        return ret

    @staticmethod
    def new_dataset_mount(dataset_id, target_path):
        """一个dataset类型的训练数据

        :param dataset_id:  数据集ID
        :type dataset_id: str
        :param  target_path:  目标挂载路径
        :type target_path: str
        :return:
        :rtype:
        """
        ret = TrainingDataConfig()
        ret.TargetPath = target_path
        ret.DataSource = "DATASET"
        ret.DatasetId = dataset_id
        return ret

    @staticmethod
    def new_mount_cfs(cfs_id, source_path, target_path):
        """新建一个cfs_nfs/cfs_turbo类型的训练数据集配置

        :param cfs_id:      CFS的ID
        :type cfs_id: str
        :param  source_path: CFS的路径
        :type source_path: str
        :param  target_path: 目标挂载路径
        :type target_path: str
        :return:
        :rtype:
        """
        ret = TrainingDataConfig()
        ret.TargetPath = target_path
        ret.DataSource = "CFS"
        ret.CfsId = cfs_id
        ret.CfsPath = source_path
        return ret
    
    @staticmethod
    def new_mount_cfs_turbofs(cfs_turbofs_id, source_path, target_path):
        """新建一个cfs_turbo类型的训练数据集配置

        :param cfs_turbofs_id: cfs_turbofs实例id
        :type cfs_turbofs_id: str
        :param  source_path: CFS的路径
        :type source_path: str
        :param  target_path: 目标挂载路径
        :type target_path: str
        :return:
        :rtype:
        """
        ret = TrainingDataConfig()
        ret.TargetPath = target_path
        ret.DataSource = "CFSTurbo"
        ret.CfsId = cfs_turbofs_id
        ret.CfsPath= source_path
        return ret
    
    @staticmethod
    def new_mount_hdfs(hdfs_id, source_path, target_path):
        """新建一个hdfs类型的训练数据集配置

        :param hdfs_id:      EMR上HDFS的ID
        :type hdfs_id: str
        :param  source_path: HDFS的路径
        :type source_path: str
        :param  target_path: 目标挂载路径
        :type target_path: str
        :return:
        :rtype:
        """
        ret = TrainingDataConfig()
        ret.TargetPath = target_path
        ret.DataSource = "HDFS"
        ret.HdfsId = hdfs_id
        ret.HdfsPath = source_path
        return ret

    @staticmethod
    def new_mount_wedata_hdfs(wedata_id, source_path):
        """新建一个wedata hdfs类型的训练数据集配置

        :param wedata_id:     wedata数据源id
        :type wedata_id: int
        :param  source_path: HDFS的路径
        :type source_path: str
        :return:
        :rtype:
        """
        ret = TrainingDataConfig()
        ret.TargetPath = None
        ret.DataSource = "WEDATA_HDFS"
        ret.WedataId = wedata_id
        ret.HdfsPath = source_path
        return ret

    @staticmethod
    def new_dataset(id_target_dict):
        """ Deprecated !
        新建一个dataset类型的训练数据集配置

        :param id_target_dict:  数据集信息。 dataset id -> 下载的目标路径
        :type id_target_dict:   dict
        :return:
        :rtype:
        """
        ret = TrainingDataConfig()
        ret.DataSource = "DATASET"
        ret.DataConfigDict = id_target_dict
        return ret

    @staticmethod
    def new_cos_data(cos_str_target_dict):
        """Deprecated !
        新建一个cos类型的训练数据集配置

        :param cos_str_target_dict:     数据集信息。  <bucket>/<cos path>/ -> 下载的目标路径
        :type cos_str_target_dict:      dict
        :return:
        :rtype:
        """
        ret = TrainingDataConfig()
        ret.DataSource = "COS"
        ret.DataConfigDict = cos_str_target_dict
        return ret
    
    @staticmethod
    def new_algo_model(ai_market_algo_id, ai_market_algo_group, target_path):
        """新建一个内置大模型训练数据配置

        :param ai_market_algo_id: 大模型算法id
        :type ai_market_algo_id: str
        :param ai_market_algo_group: 大模型算法系列
        :type ai_market_algo_id: str
        :param  target_path: 目标挂载路径
        :type target_path: str
        :return:
        :rtype:
        """
        ret = TrainingDataConfig()
        ret.TargetPath = target_path
        ret.DataSource = "AIMarket_Algo_Data"
        ret.AIMarketAlgoId = ai_market_algo_id
        ret.AIMarketAlgoGroup = ai_market_algo_group
        ret.DataSourceUsage = "BUILTIN_MODEL"
        return ret
    
    #deprecated
    @staticmethod
    def new_ai_market_algo(ai_market_algo_id, target_path):
        """新建一个内置大模型训练数据配置

        :param ai_market_algo_id: 大模型算法id
        :type ai_market_algo_id: str
        :param  target_path: 目标挂载路径
        :type target_path: str
        :return:
        :rtype:
        """
        ret = TrainingDataConfig()
        ret.TargetPath = target_path
        ret.DataSource = "AIMarket_Algo_PreModel"
        ret.AIMarketAlgoId = ai_market_algo_id
        return ret

    @staticmethod
    def new_mount_goosefs(goosefs_id, source_path, namespace, target_path):
        """新建一个goosefs类型的训练数据集配置

        :param goosefs_id: goosefs实例id
        :type goosefs_id: str
        :param  target_path: 目标挂载路径
        :type target_path: str
        :return:
        :rtype:
        """
        ret = TrainingDataConfig()
        ret.TargetPath = target_path
        ret.DataSource = "GooseFS"
        ret.GooseFSId = goosefs_id
        ret.GooseFSNameSpace = namespace
        ret.GooseFSPath = source_path
        return ret

    @staticmethod
    def new_mount_goosefsx(goosefsx_id, goosefsx_path, target_path):
        """新建一个goosefsx类型的存储配置

        :param goosefsx_id: goosefsx实例id
        :type goosefsx_id: str
        :param goosefsx_path: goosefsx路径
        :type goosefsx_path: str
        :param  target_path: 目标挂载路径
        :type target_path: str
        :return:
        :rtype:
        """
        ret = TrainingDataConfig()
        ret.TargetPath = target_path
        ret.DataSource = "GooseFSx"
        ret.GooseFSId = goosefsx_id
        ret.GooseFSxPath = goosefsx_path
        return ret


    
class ReasoningEnvironment:
    def __init__(self, source, image_key=None, image_type=None, image_url=None, registry_region=None, registry_id=None):
        self.Source = source
        self.ImageKey = image_key
        self.ImageType = image_type
        self.ImageUrl = image_url
        self.RegistryRegion = registry_region
        self.RegistryId = registry_id

    @staticmethod
    def new_system_environment(image_key):
        """平台内置的运行环境

        :param image_key:   镜像标识。通过 describe_system_reasoning_images() 查看列表
        :type image_key:    str
        :return:
        :rtype:
        """
        return ReasoningEnvironment("SYSTEM", image_key)

    @staticmethod
    def new_custom_environment(image_type, image_url, registry_region=None, registry_id=None):
        """自定义的推理运行环境

        :param image_type:      腾讯云容器镜像服务的镜像类型，如"CCR"
        :type image_type:       str
        :param image_url:       腾讯云容器镜像服务的镜像地址
        :type image_url:        str
        :param registry_region: 腾讯云容器镜像服务的镜像仓库的域
        :type registry_region:  str
        :param registry_id:     腾讯云容器镜像服务的镜像仓库ID
        :type registry_id:      str
        :return:
        :rtype:
        """
        if image_type not in IMAGE_TYPES:
            raise TencentCloudSDKException(message='image_type not must in {}'.format(IMAGE_TYPES))
        return ReasoningEnvironment("CUSTOM",
                                    image_type=image_type,
                                    image_url=image_url,
                                    registry_region=registry_region,
                                    registry_id=registry_id)

class CosPathInfo:
    def __init__(self, bucket, path, region=None, uin=None, sub_uin=None):
        self.Bucket = bucket
        self.Region = region if region is not None else os.getenv("REGION")
        self.Path = path
        self.Uin = uin
        self.SubUin = sub_uin


class ModelInfo:
    def __init__(self):
        self.ModelId = None
        self.ModelName = None
        self.ModelVersionId = None
        self.ModelVersion = None
        self.ModelSource = None
        self.ModelType = None
        self.CosPathInfo = None
        self.AlgorithmFramework = None

    @staticmethod
    def new_normal_model(model_name, model_version):
        """默认模型

        :param model_name: 模型名称
        :type model_name: str
        :param model_version: 模型版本
        :type model_version: str
        :return:
        """
        ret = ModelInfo._new_model_info(model_name, model_version)
        ret.ModelType = "NORMAL"
        return ret

    @staticmethod
    def new_accelerate_model(model_name, model_version):
        """已加速模型

        :param model_name: 模型名称
        :type model_name: str
        :param model_version: 模型版本
        :type model_version: str
        :return:
        """
        ret = ModelInfo._new_model_info(model_name, model_version)
        ret.ModelType = "ACCELERATE"
        return ret

    @staticmethod
    def _new_model_info(model_name, model_version):
        ret = ModelInfo()
        ret.ModelName = model_name
        ret.ModelVersion = model_version
        return ret

class ModelConfigInfo:
    """模型信息

    """
    def __init__(self, model_id, model_name, model_version_id, model_version, model_source, cos_path_info=None,
                 algorithm_framework=None, model_type=None):
        """

        :param model_id: 模型ID
        :type model_id: str
        :param model_name: 模型名
        :type model_name: str
        :param model_version_id: 模型版本ID，DescribeTrainingModelVersion 查询模型接口时的id
        :type model_version_id: str
        :param model_version: 模型版本
        :type model_version: str
        :param model_source: 模型来源
        :type model_source :str
        :param cos_path_info : cos路径信息
        :type cos_path_info: :class:`tikit.tencentcloud.tione.v20211111.models.CosPathInfo`
        :param algorithm_framework: 模型对应的算法框架，预留
        :type algorithm_framework: str
        :param model_type: 模型类型
        :type model_type: str
        """

        self.ModelId = model_id
        self.ModelName = model_name
        self.ModelVersionId = model_version_id
        self.ModelVersion = model_version
        self.ModelSource = model_source
        self.CosPathInfo = cos_path_info
        self.AlgorithmFramework = algorithm_framework
        self.ModelType = model_type

    @staticmethod
    def new_model_reference(model_id, model_name, model_version_id, model_version, model_source, cos_path_info=None,
                            algorithm_framework=None, model_type=None):
        """

        :param model_id: 模型ID
        :type model_id: str
        :param model_name: 模型名
        :type model_name: str
        :param model_version_id: 模型版本ID，DescribeTrainingModelVersion 查询模型接口时的id
        :type model_version_id: str
        :param model_version: 模型版本
        :type model_version: str
        :param model_source: 模型来源
        :type model_source :str
        :param cos_path_info : cos路径信息
        :type cos_path_info: :class:`tikit.tencentcloud.tione.v20211111.models.CosPathInfo`
        :param algorithm_framework: 模型对应的算法框架，预留
        :type algorithm_framework: str
        :param model_type: 模型类型
        :type model_type: str
        """

        return ModelConfigInfo(model_id=model_id,
                               model_name=model_name,
                               model_version_id=model_version_id,
                               model_version=model_version,
                               model_source=model_source,
                               cos_path_info=cos_path_info,
                               algorithm_framework=algorithm_framework,
                               model_type=model_type)
    
    @staticmethod
    def new_model_reference_lite(model_version_id, model_type='NORMAL'):
        """

        :param model_version_id: 模型ID
        :type model_version_id: str
        """
        return ModelConfigInfo('', '', model_version_id, '', '',
                               model_type=model_type)

class ImageInfo:
    def __init__(self, image_id=None, image_name=None, image_type=None, image_url=None, registry_region=None, registry_id=None):
        self.ImageId = image_id
        self.ImageName = image_name
        self.ImageType = image_type
        self.ImageUrl = image_url
        self.RegistryRegion = registry_region
        self.RegistryId = registry_id

    @staticmethod
    def new_build_in_image(image_name, image_id):
        """内置镜像配置

        :param image_name:  镜像名称
        :type image_name:    str
        :param image_id:  镜像ID
        :type image_id:    str
        :return:
        :rtype:
        """
        return ImageInfo(image_id=image_id, image_name=image_name, image_type="SYSTEM")

    @staticmethod
    def new_custom_image(image_type, image_url, registry_region=None, registry_id=None):
        """自定义镜像配置

        :param image_type:      腾讯云容器镜像服务的镜像类型，如"CCR","TCR"
        :type image_type:       str
        :param image_url:       腾讯云容器镜像服务的镜像地址
        :type image_url:        str
        :param registry_region: 腾讯云容器镜像服务的镜像仓库的域
        :type registry_region:  str
        :param registry_id:     腾讯云容器镜像服务的镜像仓库ID
        :type registry_id:      str
        :return:
        :rtype:
        """
        return ImageInfo(image_type=image_type, image_url=image_url, registry_region=registry_region, registry_id=registry_id)


class SSHConfig:
    def __init__(self):
        self.Enable = False
        self.PublicKey = None

    @staticmethod
    def new_ssh_config(ssh_enable=True, public_key=None):
        """新建SSH配置
        :param ssh_enable: 是否开启ssh
        :type ssh_enable: bool
        :param public_key: ssh公钥信息
        :type public_key: str
        :return:
        :rtype:
        """
        ret = SSHConfig()
        ret.PublicKey = public_key
        ret.Enable = ssh_enable
        return ret

class NotebookDataConfig:
    def __init__(self):
        self.DataSource = None
        self.TargetPath = None
        self.VolumeSize = None
        self.CfsId = None
        self.CfsPath = None
        self.GooseFSId = None
        self.GooseFSPath = None
        self.GooseFSNameSpace = None
        self.GooseFSxId = None
        self.GooseFSxPath = None
        self.CFSTurboId = None
        self.CFSTurboPath = None
        self.InstanceId = None

    @staticmethod
    def new_mount_cloud_premium(volume_size, target_path):
        """新建一个高性能云硬盘类型的存储配置

        :param volume_size:
        :type volume_size: int
        :param  target_path: 目标挂载路径
        :type target_path: str
        :return:
        :rtype:
        """
        ret = NotebookDataConfig()
        ret.TargetPath = target_path
        ret.DataSource = "CLOUD_PREMIUM"
        ret.VolumeSize = volume_size
        return ret

    @staticmethod
    def new_mount_cloud_ssd(volume_size, target_path):
        """新建一个SSD云硬盘类型的存储配置

        :param volume_size:
        :type volume_size: int
        :param  target_path: 目标挂载路径
        :type target_path: str
        :return:
        :rtype:
        """
        ret = NotebookDataConfig()
        ret.TargetPath = target_path
        ret.DataSource = "CLOUD_SSD"
        ret.VolumeSize = volume_size
        return ret

    @staticmethod
    def new_mount_cfs(cfs_id, source_path, target_path):
        """新建一个cfs类型的存储配置

        :param cfs_id:      CFS的ID
        :type cfs_id: str
        :param  source_path: CFS的路径
        :type source_path: str
        :param  target_path: 目标挂载路径
        :type target_path: str
        :return:
        :rtype:
        """
        ret = NotebookDataConfig()
        ret.TargetPath = target_path
        ret.DataSource = "CFS"
        ret.CfsId = cfs_id
        ret.CfsPath = source_path
        return ret

    @staticmethod
    def new_mount_goosefs(goosefs_id, namespace, sub_path, target_path):
        """新建一个goosefs类型的存储配置

        :param goosefs_id: goosefs实例id
        :type goosefs_id: str
        :param  namespace: 命名空间
        :type namespace: str
        :param  sub_path: cos子路径
        :type sub_path: str
        :param  target_path: 目标挂载路径
        :type target_path: str
        :return:
        :rtype:
        """
        ret = NotebookDataConfig()
        ret.TargetPath = target_path
        ret.DataSource = "GooseFS"
        ret.GooseFSNameSpace = namespace
        ret.GooseFSPath = sub_path
        ret.GooseFSId = goosefs_id
        return ret

    @staticmethod
    def new_mount_goosefsx(goosefsx_id, goosefsx_path, target_path):
        """新建一个goosefsx类型的存储配置

        :param goosefsx_id: goosefsx实例id
        :type goosefsx_id: str
        :param goosefsx_path: goosefsx路径
        :type goosefsx_path: str
        :param  target_path: 目标挂载路径
        :type target_path: str
        :return:
        :rtype:
        """
        ret = NotebookDataConfig()
        ret.TargetPath = target_path
        ret.DataSource = "GooseFSx"
        ret.GooseFSId = goosefsx_id
        ret.GooseFSxPath = goosefsx_path
        return ret

    @staticmethod
    def new_mount_cfs_turbofs(cfs_turbofs_id, source_path, target_path):
        """新建一个turbocfs类型的存储配置

        :param cfs_turbofs_id: cfs_turbofs实例id
        :type cfs_turbofs_id: str
        :param  source_path: CFS的路径
        :type source_path: str
        :param  target_path: 目标挂载路径
        :type target_path: str
        :return:
        :rtype:
        """
        ret = NotebookDataConfig()
        ret.TargetPath = target_path
        ret.DataSource = "CFS_TURBO"
        ret.CfsId = cfs_turbofs_id
        ret.CfsPath= source_path
        return ret

    @staticmethod
    def new_mount_local_disk(instance_id, target_path):
        """新建一个本地磁盘类型的存储配置

        :param instance_id: 节点id
        :type instance_id: str
        :param  target_path: 目标挂载路径
        :type target_path: str
        :return:
        :rtype:
        """
        ret = NotebookDataConfig()
        ret.TargetPath = target_path
        ret.DataSource = "LOCAL_DISK"
        ret.InstanceId = instance_id
        return ret



# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json

from tikit.tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
from tikit.tencentcloud.common.abstract_client import AbstractClient
from tikit.tencentcloud.emr.v20190103 import models


class EmrClient(AbstractClient):
    _apiVersion = '2019-01-03'
    _endpoint = 'emr.tencentcloudapi.com'
    _service = 'emr'


    def DescribeClusterNodes(self, request):
        """查询硬件节点信息

        :param request: Request instance for DescribeClusterNodes.
        :type request: :class:`tikit.tencentcloud.emr.v20190103.models.DescribeClusterNodesRequest`
        :rtype: :class:`tikit.tencentcloud.emr.v20190103.models.DescribeClusterNodesResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeClusterNodes", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeClusterNodesResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeKeyTabFile(self, request):
        """导出Keytab文件（用户管理）

        :param request: Request instance for DescribeKeyTabFile.
        :type request: :class:`tikit.tencentcloud.emr.v20190103.models.DescribeKeyTabFileRequest`
        :rtype: :class:`tikit.tencentcloud.emr.v20190103.models.DescribeKeyTabFileResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeKeyTabFile", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeKeyTabFileResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeServiceConfs(self, request):
        """查询服务配置

        :param request: Request instance for DescribeServiceConfs.
        :type request: :class:`tikit.tencentcloud.emr.v20190103.models.DescribeServiceConfsRequest`
        :rtype: :class:`tikit.tencentcloud.emr.v20190103.models.DescribeServiceConfsResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeServiceConfs", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeServiceConfsResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeUserManagerUserList(self, request):
        """查询用户列表（用户管理）

        :param request: Request instance for DescribeUserManagerUserList.
        :type request: :class:`tikit.tencentcloud.emr.v20190103.models.DescribeUserManagerUserListRequest`
        :rtype: :class:`tikit.tencentcloud.emr.v20190103.models.DescribeUserManagerUserListResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeUserManagerUserList", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeUserManagerUserListResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json

from tikit.tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
from tikit.tencentcloud.common.abstract_client import AbstractClient
from tikit.tencentcloud.cfs.v20190719 import models


class CfsClient(AbstractClient):
    _apiVersion = '2019-07-19'
    _endpoint = 'cfs.tencentcloudapi.com'
    _service = 'cfs'


    def BindAutoSnapshotPolicy(self, request):
        """文件系统绑定快照策略，可以同时绑定多个fs，一个fs 只能跟一个策略绑定

        :param request: Request instance for BindAutoSnapshotPolicy.
        :type request: :class:`tencentcloud.cfs.v20190719.models.BindAutoSnapshotPolicyRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.BindAutoSnapshotPolicyResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("BindAutoSnapshotPolicy", params, headers=headers)
            response = json.loads(body)
            model = models.BindAutoSnapshotPolicyResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def CreateAutoSnapshotPolicy(self, request):
        """创建定期快照策略

        :param request: Request instance for CreateAutoSnapshotPolicy.
        :type request: :class:`tencentcloud.cfs.v20190719.models.CreateAutoSnapshotPolicyRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.CreateAutoSnapshotPolicyResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("CreateAutoSnapshotPolicy", params, headers=headers)
            response = json.loads(body)
            model = models.CreateAutoSnapshotPolicyResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def CreateCfsFileSystem(self, request):
        """用于添加新文件系统

        :param request: Request instance for CreateCfsFileSystem.
        :type request: :class:`tencentcloud.cfs.v20190719.models.CreateCfsFileSystemRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.CreateCfsFileSystemResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("CreateCfsFileSystem", params, headers=headers)
            response = json.loads(body)
            model = models.CreateCfsFileSystemResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def CreateCfsPGroup(self, request):
        """本接口（CreateCfsPGroup）用于创建权限组

        :param request: Request instance for CreateCfsPGroup.
        :type request: :class:`tencentcloud.cfs.v20190719.models.CreateCfsPGroupRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.CreateCfsPGroupResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("CreateCfsPGroup", params, headers=headers)
            response = json.loads(body)
            model = models.CreateCfsPGroupResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def CreateCfsRule(self, request):
        """本接口（CreateCfsRule）用于创建权限组规则。

        :param request: Request instance for CreateCfsRule.
        :type request: :class:`tencentcloud.cfs.v20190719.models.CreateCfsRuleRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.CreateCfsRuleResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("CreateCfsRule", params, headers=headers)
            response = json.loads(body)
            model = models.CreateCfsRuleResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def CreateCfsSnapshot(self, request):
        """创建文件系统快照

        :param request: Request instance for CreateCfsSnapshot.
        :type request: :class:`tencentcloud.cfs.v20190719.models.CreateCfsSnapshotRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.CreateCfsSnapshotResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("CreateCfsSnapshot", params, headers=headers)
            response = json.loads(body)
            model = models.CreateCfsSnapshotResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def CreateMigrationTask(self, request):
        """用于创建迁移任务。
        此接口需提交工单，开启白名单之后才能使用。

        :param request: Request instance for CreateMigrationTask.
        :type request: :class:`tencentcloud.cfs.v20190719.models.CreateMigrationTaskRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.CreateMigrationTaskResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("CreateMigrationTask", params, headers=headers)
            response = json.loads(body)
            model = models.CreateMigrationTaskResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def DeleteAutoSnapshotPolicy(self, request):
        """删除快照定期策略

        :param request: Request instance for DeleteAutoSnapshotPolicy.
        :type request: :class:`tencentcloud.cfs.v20190719.models.DeleteAutoSnapshotPolicyRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.DeleteAutoSnapshotPolicyResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DeleteAutoSnapshotPolicy", params, headers=headers)
            response = json.loads(body)
            model = models.DeleteAutoSnapshotPolicyResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def DeleteCfsFileSystem(self, request):
        """用于删除文件系统

        :param request: Request instance for DeleteCfsFileSystem.
        :type request: :class:`tencentcloud.cfs.v20190719.models.DeleteCfsFileSystemRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.DeleteCfsFileSystemResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DeleteCfsFileSystem", params, headers=headers)
            response = json.loads(body)
            model = models.DeleteCfsFileSystemResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def DeleteCfsPGroup(self, request):
        """本接口（DeleteCfsPGroup）用于删除权限组。

        :param request: Request instance for DeleteCfsPGroup.
        :type request: :class:`tencentcloud.cfs.v20190719.models.DeleteCfsPGroupRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.DeleteCfsPGroupResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DeleteCfsPGroup", params, headers=headers)
            response = json.loads(body)
            model = models.DeleteCfsPGroupResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def DeleteCfsRule(self, request):
        """本接口（DeleteCfsRule）用于删除权限组规则。

        :param request: Request instance for DeleteCfsRule.
        :type request: :class:`tencentcloud.cfs.v20190719.models.DeleteCfsRuleRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.DeleteCfsRuleResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DeleteCfsRule", params, headers=headers)
            response = json.loads(body)
            model = models.DeleteCfsRuleResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def DeleteCfsSnapshot(self, request):
        """删除文件系统快照

        :param request: Request instance for DeleteCfsSnapshot.
        :type request: :class:`tencentcloud.cfs.v20190719.models.DeleteCfsSnapshotRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.DeleteCfsSnapshotResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DeleteCfsSnapshot", params, headers=headers)
            response = json.loads(body)
            model = models.DeleteCfsSnapshotResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def DeleteMigrationTask(self, request):
        """用于删除迁移任务。
        此接口需提交工单，开启白名单之后才能使用。

        :param request: Request instance for DeleteMigrationTask.
        :type request: :class:`tencentcloud.cfs.v20190719.models.DeleteMigrationTaskRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.DeleteMigrationTaskResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DeleteMigrationTask", params, headers=headers)
            response = json.loads(body)
            model = models.DeleteMigrationTaskResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def DeleteMountTarget(self, request):
        """本接口（DeleteMountTarget）用于删除挂载点
        说明：2022年6月1日之后创建的CFS文件系统删除时无需单独调用删除挂载点操作，此API仅适用老版本的CFS实例。

        :param request: Request instance for DeleteMountTarget.
        :type request: :class:`tencentcloud.cfs.v20190719.models.DeleteMountTargetRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.DeleteMountTargetResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DeleteMountTarget", params, headers=headers)
            response = json.loads(body)
            model = models.DeleteMountTargetResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def DeleteUserQuota(self, request):
        """指定条件删除文件系统配额（仅部分Turbo实例能使用，若需要调用请提交工单与我们联系）

        :param request: Request instance for DeleteUserQuota.
        :type request: :class:`tencentcloud.cfs.v20190719.models.DeleteUserQuotaRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.DeleteUserQuotaResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DeleteUserQuota", params, headers=headers)
            response = json.loads(body)
            model = models.DeleteUserQuotaResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def DescribeAutoSnapshotPolicies(self, request):
        """查询文件系统快照定期策略列表信息

        :param request: Request instance for DescribeAutoSnapshotPolicies.
        :type request: :class:`tencentcloud.cfs.v20190719.models.DescribeAutoSnapshotPoliciesRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.DescribeAutoSnapshotPoliciesResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeAutoSnapshotPolicies", params, headers=headers)
            response = json.loads(body)
            model = models.DescribeAutoSnapshotPoliciesResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def DescribeAvailableZoneInfo(self, request):
        """本接口（DescribeAvailableZoneInfo）用于查询区域的可用情况。

        :param request: Request instance for DescribeAvailableZoneInfo.
        :type request: :class:`tencentcloud.cfs.v20190719.models.DescribeAvailableZoneInfoRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.DescribeAvailableZoneInfoResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeAvailableZoneInfo", params, headers=headers)
            response = json.loads(body)
            model = models.DescribeAvailableZoneInfoResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def DescribeBucketList(self, request):
        """用于获取数据源桶列表。
        此接口需提交工单，开启白名单之后才能使用。

        :param request: Request instance for DescribeBucketList.
        :type request: :class:`tencentcloud.cfs.v20190719.models.DescribeBucketListRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.DescribeBucketListResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeBucketList", params, headers=headers)
            response = json.loads(body)
            model = models.DescribeBucketListResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def DescribeCfsFileSystemClients(self, request):
        """查询挂载该文件系统的客户端。此功能需要客户端安装CFS监控插件。

        :param request: Request instance for DescribeCfsFileSystemClients.
        :type request: :class:`tencentcloud.cfs.v20190719.models.DescribeCfsFileSystemClientsRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.DescribeCfsFileSystemClientsResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeCfsFileSystemClients", params, headers=headers)
            response = json.loads(body)
            model = models.DescribeCfsFileSystemClientsResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def DescribeCfsFileSystems(self, request):
        """本接口（DescribeCfsFileSystems）用于查询文件系统

        :param request: Request instance for DescribeCfsFileSystems.
        :type request: :class:`tencentcloud.cfs.v20190719.models.DescribeCfsFileSystemsRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.DescribeCfsFileSystemsResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeCfsFileSystems", params, headers=headers)
            response = json.loads(body)
            model = models.DescribeCfsFileSystemsResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def DescribeCfsPGroups(self, request):
        """本接口（DescribeCfsPGroups）用于查询权限组列表。

        :param request: Request instance for DescribeCfsPGroups.
        :type request: :class:`tencentcloud.cfs.v20190719.models.DescribeCfsPGroupsRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.DescribeCfsPGroupsResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeCfsPGroups", params, headers=headers)
            response = json.loads(body)
            model = models.DescribeCfsPGroupsResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def DescribeCfsRules(self, request):
        """本接口（DescribeCfsRules）用于查询权限组规则列表。

        :param request: Request instance for DescribeCfsRules.
        :type request: :class:`tencentcloud.cfs.v20190719.models.DescribeCfsRulesRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.DescribeCfsRulesResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeCfsRules", params, headers=headers)
            response = json.loads(body)
            model = models.DescribeCfsRulesResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def DescribeCfsServiceStatus(self, request):
        """本接口（DescribeCfsServiceStatus）用于查询用户使用CFS的服务状态。

        :param request: Request instance for DescribeCfsServiceStatus.
        :type request: :class:`tencentcloud.cfs.v20190719.models.DescribeCfsServiceStatusRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.DescribeCfsServiceStatusResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeCfsServiceStatus", params, headers=headers)
            response = json.loads(body)
            model = models.DescribeCfsServiceStatusResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def DescribeCfsSnapshotOverview(self, request):
        """文件系统快照概览

        :param request: Request instance for DescribeCfsSnapshotOverview.
        :type request: :class:`tencentcloud.cfs.v20190719.models.DescribeCfsSnapshotOverviewRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.DescribeCfsSnapshotOverviewResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeCfsSnapshotOverview", params, headers=headers)
            response = json.loads(body)
            model = models.DescribeCfsSnapshotOverviewResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def DescribeCfsSnapshots(self, request):
        """查询文件系统快照列表

        :param request: Request instance for DescribeCfsSnapshots.
        :type request: :class:`tencentcloud.cfs.v20190719.models.DescribeCfsSnapshotsRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.DescribeCfsSnapshotsResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeCfsSnapshots", params, headers=headers)
            response = json.loads(body)
            model = models.DescribeCfsSnapshotsResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def DescribeMigrationTasks(self, request):
        """用于获取迁移任务列表。
        此接口需提交工单，开启白名单之后才能使用。

        :param request: Request instance for DescribeMigrationTasks.
        :type request: :class:`tencentcloud.cfs.v20190719.models.DescribeMigrationTasksRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.DescribeMigrationTasksResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeMigrationTasks", params, headers=headers)
            response = json.loads(body)
            model = models.DescribeMigrationTasksResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def DescribeMountTargets(self, request):
        """本接口（DescribeMountTargets）用于查询文件系统挂载点信息

        :param request: Request instance for DescribeMountTargets.
        :type request: :class:`tencentcloud.cfs.v20190719.models.DescribeMountTargetsRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.DescribeMountTargetsResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeMountTargets", params, headers=headers)
            response = json.loads(body)
            model = models.DescribeMountTargetsResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def DescribeSnapshotOperationLogs(self, request):
        """查询快照操作日志

        :param request: Request instance for DescribeSnapshotOperationLogs.
        :type request: :class:`tencentcloud.cfs.v20190719.models.DescribeSnapshotOperationLogsRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.DescribeSnapshotOperationLogsResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeSnapshotOperationLogs", params, headers=headers)
            response = json.loads(body)
            model = models.DescribeSnapshotOperationLogsResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def DescribeUserQuota(self, request):
        """查询文件系统配额（仅部分Turbo实例能使用，若需要调用请提交工单与我们联系）

        :param request: Request instance for DescribeUserQuota.
        :type request: :class:`tencentcloud.cfs.v20190719.models.DescribeUserQuotaRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.DescribeUserQuotaResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeUserQuota", params, headers=headers)
            response = json.loads(body)
            model = models.DescribeUserQuotaResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def ModifyFileSystemAutoScaleUpRule(self, request):
        """用来设置文件系统扩容策略

        :param request: Request instance for ModifyFileSystemAutoScaleUpRule.
        :type request: :class:`tencentcloud.cfs.v20190719.models.ModifyFileSystemAutoScaleUpRuleRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.ModifyFileSystemAutoScaleUpRuleResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("ModifyFileSystemAutoScaleUpRule", params, headers=headers)
            response = json.loads(body)
            model = models.ModifyFileSystemAutoScaleUpRuleResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def ScaleUpFileSystem(self, request):
        """该接口用于对turbo 文件系统扩容使用

        :param request: Request instance for ScaleUpFileSystem.
        :type request: :class:`tencentcloud.cfs.v20190719.models.ScaleUpFileSystemRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.ScaleUpFileSystemResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("ScaleUpFileSystem", params, headers=headers)
            response = json.loads(body)
            model = models.ScaleUpFileSystemResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def SetUserQuota(self, request):
        """设置文件系统配额，提供UID/GID的配额设置的接口（仅部分Turbo实例能使用，若需要调用请提交工单与我们联系）

        :param request: Request instance for SetUserQuota.
        :type request: :class:`tencentcloud.cfs.v20190719.models.SetUserQuotaRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.SetUserQuotaResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("SetUserQuota", params, headers=headers)
            response = json.loads(body)
            model = models.SetUserQuotaResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def SignUpCfsService(self, request):
        """本接口（SignUpCfsService）用于开通CFS服务。

        :param request: Request instance for SignUpCfsService.
        :type request: :class:`tencentcloud.cfs.v20190719.models.SignUpCfsServiceRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.SignUpCfsServiceResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("SignUpCfsService", params, headers=headers)
            response = json.loads(body)
            model = models.SignUpCfsServiceResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def StopMigrationTask(self, request):
        """用于终止迁移任务。
        此接口需提交工单，开启白名单之后才能使用。

        :param request: Request instance for StopMigrationTask.
        :type request: :class:`tencentcloud.cfs.v20190719.models.StopMigrationTaskRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.StopMigrationTaskResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("StopMigrationTask", params, headers=headers)
            response = json.loads(body)
            model = models.StopMigrationTaskResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def UnbindAutoSnapshotPolicy(self, request):
        """解除文件系统绑定的快照策略

        :param request: Request instance for UnbindAutoSnapshotPolicy.
        :type request: :class:`tencentcloud.cfs.v20190719.models.UnbindAutoSnapshotPolicyRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.UnbindAutoSnapshotPolicyResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("UnbindAutoSnapshotPolicy", params, headers=headers)
            response = json.loads(body)
            model = models.UnbindAutoSnapshotPolicyResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def UpdateAutoSnapshotPolicy(self, request):
        """更新定期自动快照策略

        :param request: Request instance for UpdateAutoSnapshotPolicy.
        :type request: :class:`tencentcloud.cfs.v20190719.models.UpdateAutoSnapshotPolicyRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.UpdateAutoSnapshotPolicyResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("UpdateAutoSnapshotPolicy", params, headers=headers)
            response = json.loads(body)
            model = models.UpdateAutoSnapshotPolicyResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def UpdateCfsFileSystemName(self, request):
        """本接口（UpdateCfsFileSystemName）用于更新文件系统名

        :param request: Request instance for UpdateCfsFileSystemName.
        :type request: :class:`tencentcloud.cfs.v20190719.models.UpdateCfsFileSystemNameRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.UpdateCfsFileSystemNameResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("UpdateCfsFileSystemName", params, headers=headers)
            response = json.loads(body)
            model = models.UpdateCfsFileSystemNameResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def UpdateCfsFileSystemPGroup(self, request):
        """本接口（UpdateCfsFileSystemPGroup）用于更新文件系统所使用的权限组

        :param request: Request instance for UpdateCfsFileSystemPGroup.
        :type request: :class:`tencentcloud.cfs.v20190719.models.UpdateCfsFileSystemPGroupRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.UpdateCfsFileSystemPGroupResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("UpdateCfsFileSystemPGroup", params, headers=headers)
            response = json.loads(body)
            model = models.UpdateCfsFileSystemPGroupResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def UpdateCfsFileSystemSizeLimit(self, request):
        """本接口（UpdateCfsFileSystemSizeLimit）用于更新文件系统存储容量限制。

        :param request: Request instance for UpdateCfsFileSystemSizeLimit.
        :type request: :class:`tencentcloud.cfs.v20190719.models.UpdateCfsFileSystemSizeLimitRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.UpdateCfsFileSystemSizeLimitResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("UpdateCfsFileSystemSizeLimit", params, headers=headers)
            response = json.loads(body)
            model = models.UpdateCfsFileSystemSizeLimitResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def UpdateCfsPGroup(self, request):
        """本接口（UpdateCfsPGroup）更新权限组信息。

        :param request: Request instance for UpdateCfsPGroup.
        :type request: :class:`tencentcloud.cfs.v20190719.models.UpdateCfsPGroupRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.UpdateCfsPGroupResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("UpdateCfsPGroup", params, headers=headers)
            response = json.loads(body)
            model = models.UpdateCfsPGroupResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def UpdateCfsRule(self, request):
        """本接口（UpdateCfsRule）用于更新权限规则。

        :param request: Request instance for UpdateCfsRule.
        :type request: :class:`tencentcloud.cfs.v20190719.models.UpdateCfsRuleRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.UpdateCfsRuleResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("UpdateCfsRule", params, headers=headers)
            response = json.loads(body)
            model = models.UpdateCfsRuleResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def UpdateCfsSnapshotAttribute(self, request):
        """更新文件系统快照名称及保留时长

        :param request: Request instance for UpdateCfsSnapshotAttribute.
        :type request: :class:`tencentcloud.cfs.v20190719.models.UpdateCfsSnapshotAttributeRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.UpdateCfsSnapshotAttributeResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("UpdateCfsSnapshotAttribute", params, headers=headers)
            response = json.loads(body)
            model = models.UpdateCfsSnapshotAttributeResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


    def UpdateFileSystemBandwidthLimit(self, request):
        """更新文件系统吞吐
        仅吞吐型支持此接口

        :param request: Request instance for UpdateFileSystemBandwidthLimit.
        :type request: :class:`tencentcloud.cfs.v20190719.models.UpdateFileSystemBandwidthLimitRequest`
        :rtype: :class:`tencentcloud.cfs.v20190719.models.UpdateFileSystemBandwidthLimitResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("UpdateFileSystemBandwidthLimit", params, headers=headers)
            response = json.loads(body)
            model = models.UpdateFileSystemBandwidthLimitResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))


from email.policy import default
import json
import os
import click

from importlib.metadata import requires
from .client import Client

cred_path = os.path.join(os.path.expanduser("~"), ".tikit/credential")

from prettytable import PrettyTable

def pretty_print_dict_list(l):
    if not l:
        return None
    table = PrettyTable()
    cols = l[0].keys()
    for col in cols:
        table.add_column(col, [])
    for dct in l:
        table.add_row([dct.get(c, '') for c in cols])
    return table

@click.group()
def cli():
    pass


@cli.command('config', help='configure to access qcloud api')
@click.option('--secret_id', required=True,
              help='your secret id to access qcloud api')
@click.option('--secret_key', required=True,
              help='your secret key to access qcloud api')
@click.option('--region', default='ap-guangzhou', help='your region name')
def config_create_cmd(secret_id, secret_key, region):
    cred_path_dir = os.path.dirname(cred_path)
    if not os.path.isdir(cred_path_dir):
        os.makedirs(cred_path_dir)
    obj = {}
    obj['secret_id'] = secret_id
    obj['secret_key'] = secret_key
    obj['region'] = region
    with open(cred_path, "w") as f:
        json.dump(obj, f, indent=2)
    click.echo(f'credential file saved to {cred_path}')


def init_client() -> Client:
    if not os.path.exists(cred_path):
        raise click.ClickException(
            'Please run "tikit config" to '
            'configure the secret first')
    with open(cred_path, 'r') as f:
        cred = json.loads(f.read())
    return Client(cred['secret_id'], cred['secret_key'], region=cred['region'])


@cli.command('create', help='create tione resource')
@click.argument('resource', type=click.Choice(['service']))
@click.option('--init_file', is_flag=True, default=False,
              help='create a config file template')
@click.option('-f', '--filename', default='',
              help='that contains the configuration to create')
def create_cmd(resource, init_file, filename):
    client = init_client()
    if resource == 'service':
        try:
            if init_file is True:
                # 生成描述模版文件
                filename = (filename if filename != ''
                            else 'service-config.yaml')
                dirname = os.path.dirname(__file__)
                with open(os.path.join(dirname, 'templates',
                                       'service_config.yaml'), 'r') as infile:
                    config_template = infile.read()
                with open(filename, 'w') as outfile:
                    outfile.write(config_template)
            else:
                msg = client._create_model_service_from_file(filename)
                click.echo(msg)
        except Exception as e:
            raise e
            # raise click.ClickException(str(e))


@cli.command('update', help='update tione resource')
@click.argument('resource', type=click.Choice(['service']))
@click.option('-f', '--filename', default='',
              help='that contains the configuration to create')
def update_cmd(resource, filename):
    client = init_client()
    if resource == 'service':
        try:
            msg = client._modify_model_service_from_file(filename)
            click.echo(msg)
        except Exception as e:
            raise click.ClickException(str(e))


@cli.command('balance', help='balance the traffic')
@click.argument('name', metavar='<NAME>|<SERVICE_GROUP_ID>')
@click.argument('weights', nargs=2, metavar='<VERSION1>:<WEIGHT1> ...')
def balance_cmd(name, weights):
    if not weights:
        raise click.ClickException('weights shoud not be empty')
    m = {}
    import re
    for wei in weights:
        group = wei.split(':')
        if len(group) != 2:
            raise click.ClickException(f'{wei} is invalid, '
                                       f'it should be like v1:30')
        group[0] = re.sub('VERSION', '', group[0])
        group[0] = re.sub('version', '', group[0])
        m[group[0].lstrip('vV')] = int(group[1])
    try:
        client = init_client()
        service_group_id = client.get_service_group_id_by_name(name)
        mm = {}
        for v, w in m.items():
            mm[f'{service_group_id}-{v}'] = w
        resp = client.modify_service_group_weights(service_group_id, mm)
        click.echo(f'change weights succeeded: req_id = {resp.RequestId}')
    except Exception as e:
        raise click.ClickException(str(e))


@cli.command('stop', help='stop tione resource')
@click.argument('resource', type=click.Choice(['service']))
@click.argument('name',  metavar='<ID>|(<NAME>:<VERSION>)')
def stop_cmd(resource, name: str):
    client = init_client()
    if resource == 'service':
        if ':' in name:
            group = name.split(':')
            if len(group) != 2:
                raise click.ClickException(
                    f'service name({name}) is invalid, '
                    f'should be <NAME>:<VERSION>')
            service_id = client.get_service_id_by_name(group[0], group[1])
        else:
            service_id = name
        try:
            msg = client.stop_model_service(service_id)
            click.echo(msg)
        except Exception as e:
            raise click.ClickException(str(e))


@cli.command('start', help='start tione resource')
@click.argument('resource', type=click.Choice(['service']))
@click.argument('name',  metavar='<ID>|(<NAME>:<VERSION>)')
def start_cmd(resource, name: str):
    client = init_client()
    if resource == 'service':
        if ':' in name:
            group = name.split(':')
            if len(group) != 2:
                raise click.ClickException(
                    f'service name({name}) is invalid, '
                    f'should be <NAME>:<VERSION>')
            service_id = client.get_service_id_by_name(group[0], group[1])
        else:
            service_id = name
        try:
            msg = client.start_model_service(service_id)
            click.echo(msg)
        except Exception as e:
            raise click.ClickException(str(e))


@cli.command('delete', help='delete tione resource')
@click.argument('resource', type=click.Choice(['service']))
@click.argument('name',  metavar='<ID>|(<NAME>:<VERSION>)')
def delete_cmd(resource, name: str):
    client = init_client()
    if resource == 'service':
        if ':' in name:
            group = name.split(':')
            if len(group) != 2:
                raise click.ClickException(
                    f'service name({name}) is invalid, '
                    f'should be <NAME>:<VERSION>')
            service_id = client.get_service_id_by_name(group[0], group[1])
        else:
            service_id = name
        try:
            msg = client.delete_model_service(service_id)
            click.echo(msg)
        except Exception as e:
            raise click.ClickException(str(e))


@cli.command('get', help='get info of tione resource')
@click.argument('resource', type=click.Choice(['service']))
@click.argument('name',  metavar='<ID>|(<NAME>:<VERSION>)', required=False)
def get_cmd(resource, name: str):
    client = init_client()
    if resource == 'service':
        if not name:
            # 返回所有的服务列表
            svcs = client.get_model_service_summary()
            click.echo(pretty_print_dict_list(svcs))
            return
        if ':' in name:
            group = name.split(':')
            if len(group) != 2:
                raise click.ClickException(
                    f'service name({name}) is invalid, '
                    f'should be <NAME>:<VERSION>')
            service_id = client.get_service_id_by_name(group[0], group[1])
        else:
            service_id = name
        try:
            resp = client.describe_model_service(service_id)
            click.echo(resp)
        except Exception as e:
            raise click.ClickException(str(e))


# -*- coding: utf-8 -*-
__version__ = '1.8.6.241224'
from .default_client import *
from .display_optimize import *
# from .client import Client
# from .hdfs import *
# from .hive import *
# from .models import *




# -*- coding: utf-8 -*-
import os

from hdfs import Client as HdfsClient


def upload_to_hdfs(local_path, hdfs_url, hdfs_path):
    """上传本地目录到hdfs上

    :param local_path:  本地路径
    :type local_path:   str
    :param hdfs_url:    webhdfs的地址，如：http://10.0.3.16:4008
    :type hdfs_url:     str
    :param hdfs_path:   hdfs上的路径
    :type hdfs_path:    str
    :return:            hdfs的结果路径
    :rtype:             str
    """
    hdfs_client = HdfsClient(hdfs_url)
    # 上传文件到一个不存在的目录（斜杠结尾）的时候，hdfs库会把目录当成最终文件
    if os.path.isfile(local_path) and hdfs_path.endswith("/"):
        hdfs_path = os.path.join(hdfs_path, os.path.basename(local_path))
    return hdfs_client.upload(hdfs_path, local_path)


def download_from_hdfs(hdfs_url, hdfs_path, local_path):
    """从hdfs上下载文件到本地

    :param hdfs_url:    webhdfs的地址，如：http://10.0.3.16:4008
    :type hdfs_url:     str
    :param hdfs_path:   hdfs上的路径
    :type hdfs_path:    str
    :param local_path:  本地路径
    :type local_path:   str
    :return:            本地的结果路径
    :rtype:             str
    """
    hdfs_client = HdfsClient(hdfs_url)
    path_info = hdfs_client.status(hdfs_path)
    # 下载文件到一个不存在的目录（斜杠结尾）的时候，hdfs库会把目录当成最终文件
    if path_info["type"] == "FILE" and local_path.endswith("/"):
        local_path = os.path.join(local_path, os.path.basename(hdfs_path))
    # 创建目录
    local_dir = os.path.dirname(local_path)
    if local_dir != "" and not os.path.exists(local_dir):
        os.makedirs(local_dir)
    return hdfs_client.download(hdfs_path, local_path)
